from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSCHCommandArchives.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSCH3DArchives_pb2 as TSCH3DArchives__pb2
from . import TSCHArchives_Common_pb2 as TSCHArchives__Common__pb2
from . import TSCHArchives_GEN_pb2 as TSCHArchives__GEN__pb2
from . import TSCHArchives_pb2 as TSCHArchives__pb2
from . import TSDArchives_pb2 as TSDArchives__pb2
from . import TSDCommandArchives_pb2 as TSDCommandArchives__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSSArchives_pb2 as TSSArchives__pb2
from . import TSWPArchives_pb2 as TSWPArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSCHCommandArchives.proto',
  package='TSCH',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x19TSCHCommandArchives.proto\x12\x04TSCH\x1a\x14TSCH3DArchives.proto\x1a\x19TSCHArchives_Common.proto\x1a\x16TSCHArchives_GEN.proto\x1a\x12TSCHArchives.proto\x1a\x11TSDArchives.proto\x1a\x18TSDCommandArchives.proto\x1a\x11TSKArchives.proto\x1a\x11TSPMessages.proto\x1a\x11TSSArchives.proto\x1a\x12TSWPArchives.proto\"*\n\x0eStyleOwnerPath\x12\x18\n\x05uuids\x18\x01 \x03(\x0b\x32\t.TSP.UUID\"\xc7\x03\n\x1a\x43ommandSetChartTypeArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\'\n\x0enew_chart_type\x18\x02 \x01(\x0e\x32\x0f.TSCH.ChartType\x12\'\n\x0eold_chart_type\x18\x03 \x01(\x0e\x32\x0f.TSCH.ChartType\x12,\n\x13rollback_chart_type\x18\x04 \x01(\x0e\x32\x0f.TSCH.ChartType\x12\x1a\n\x07row_ids\x18\x05 \x03(\x0b\x32\t.TSP.UUID\x12\x1d\n\ncolumn_ids\x18\x06 \x03(\x0b\x32\t.TSP.UUID\x12\x1e\n\x0bold_row_ids\x18\x07 \x03(\x0b\x32\t.TSP.UUID\x12!\n\x0eold_column_ids\x18\x08 \x03(\x0b\x32\t.TSP.UUID\x12#\n\x10rollback_row_ids\x18\t \x03(\x0b\x32\t.TSP.UUID\x12&\n\x13rollback_column_ids\x18\n \x03(\x0b\x32\t.TSP.UUID\x12\x1a\n\x12uses_captured_data\x18\x0b \x01(\x08\x12\x18\n\x10use_default_data\x18\x0c \x01(\x08\"\xde\x01\n\x19StyleSwapUndoTupleArchive\x12\"\n\nchart_info\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12&\n\tswap_type\x18\x02 \x01(\x0e\x32\x13.TSCH.StyleSwapType\x12\r\n\x05index\x18\x03 \x01(\r\x12!\n\told_value\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12!\n\tnew_value\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12 \n\rref_line_uuid\x18\x06 \x01(\x0b\x32\t.TSP.UUID\"R\n\x1aStyleSwapUndoTuplesArchive\x12\x34\n\x0bswap_tuples\x18\x01 \x03(\x0b\x32\x1f.TSCH.StyleSwapUndoTupleArchive\"y\n\x17\x43ommandStyleSwapArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x34\n\x0bundo_tuples\x18\x02 \x03(\x0b\x32\x1f.TSCH.StyleSwapUndoTupleArchive\"\xdc\x0b\n\x1e\x43ommandMutatePropertiesArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12$\n\x0crollback_cmd\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x61\n\x1bgeneric_property_delta_maps\x18\x03 \x03(\x0b\x32<.TSCH.CommandMutatePropertiesArchive.GenericPropertyDeltaMap\x12_\n\x1aparagraph_style_delta_maps\x18\x04 \x03(\x0b\x32;.TSCH.CommandMutatePropertiesArchive.ParagraphStyleDeltaMap\x12\x16\n\x0einitiatedOnWeb\x18\x05 \x01(\x08\x1a\x8f\x05\n\x17GenericPropertyDeltaMap\x12.\n\x10style_owner_path\x18\x01 \x01(\x0b\x32\x14.TSCH.StyleOwnerPath\x12\x61\n\x0b\x66orward_map\x18\x02 \x01(\x0b\x32L.TSCH.CommandMutatePropertiesArchive.GenericPropertyDeltaMap.GenericMapUnion\x12\x61\n\x0breverse_map\x18\x03 \x01(\x0b\x32L.TSCH.CommandMutatePropertiesArchive.GenericPropertyDeltaMap.GenericMapUnion\x1a\xfd\x02\n\x0fGenericMapUnion\x12\x41\n\tchart_map\x18\x02 \x01(\x0b\x32..TSCH.Generated.ChartGenericPropertyMapArchive\x12\x43\n\nlegend_map\x18\x03 \x01(\x0b\x32/.TSCH.Generated.LegendGenericPropertyMapArchive\x12\x44\n\x08\x61xis_map\x18\x04 \x01(\x0b\x32\x32.TSCH.Generated.ChartAxisGenericPropertyMapArchive\x12H\n\nseries_map\x18\x05 \x01(\x0b\x32\x34.TSCH.Generated.ChartSeriesGenericPropertyMapArchive\x12R\n\x12reference_line_map\x18\x06 \x01(\x0b\x32\x36.TSCH.Generated.ReferenceLineGenericPropertyMapArchive\x1a\xfb\x03\n\x16ParagraphStyleDeltaMap\x12.\n\x10style_owner_path\x18\x01 \x01(\x0b\x32\x14.TSCH.StyleOwnerPath\x12&\n\x1eparagraph_style_index_property\x18\x02 \x01(\r\x12q\n\x0b\x66orward_map\x18\x03 \x01(\x0b\x32\\.TSCH.CommandMutatePropertiesArchive.ParagraphStyleDeltaMap.ParagraphStylePropertyMapArchive\x12q\n\x0breverse_map\x18\x04 \x01(\x0b\x32\\.TSCH.CommandMutatePropertiesArchive.ParagraphStyleDeltaMap.ParagraphStylePropertyMapArchive\x1a\xa2\x01\n ParagraphStylePropertyMapArchive\x12>\n\x0f\x63har_properties\x18\x01 \x01(\x0b\x32%.TSWP.CharacterStylePropertiesArchive\x12>\n\x0fpara_properties\x18\x02 \x01(\x0b\x32%.TSWP.ParagraphStylePropertiesArchive\"\x82\x01\n\x1a\x43ommandScaleAllTextArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12$\n\x0crollback_cmd\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x14\n\x0cscale_factor\x18\x03 \x01(\x01\"\xb0\x07\n\x1b\x43ommandSetFontFamilyArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12$\n\x0crollback_cmd\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x17\n\x0fnew_font_family\x18\x03 \x01(\t\x12\x17\n\x0fold_font_family\x18\x04 \x01(\t\x12g\n\x1aparagraph_style_delta_maps\x18\x05 \x03(\x0b\x32\x43.TSCH.CommandSetFontFamilyArchive.SemanticParagraphStyleMutationMap\x12\x0f\n\x07is_bold\x18\x06 \x02(\x08\x12\x11\n\tis_italic\x18\x07 \x02(\x08\x1aI\n\x10StyleSemanticTag\x12&\n\tswap_type\x18\x01 \x01(\x0e\x32\x13.TSCH.StyleSwapType\x12\r\n\x05index\x18\x02 \x01(\r\x1a\xb6\x04\n!SemanticParagraphStyleMutationMap\x12N\n\x12style_semantic_tag\x18\x01 \x01(\x0b\x32\x32.TSCH.CommandSetFontFamilyArchive.StyleSemanticTag\x12&\n\x1eparagraph_style_index_property\x18\x02 \x01(\r\x12y\n\x0b\x66orward_map\x18\x03 \x01(\x0b\x32\x64.TSCH.CommandSetFontFamilyArchive.SemanticParagraphStyleMutationMap.ParagraphStylePropertyMapArchive\x12y\n\x0breverse_map\x18\x04 \x01(\x0b\x32\x64.TSCH.CommandSetFontFamilyArchive.SemanticParagraphStyleMutationMap.ParagraphStylePropertyMapArchive\x1a\xa2\x01\n ParagraphStylePropertyMapArchive\x12>\n\x0f\x63har_properties\x18\x01 \x01(\x0b\x32%.TSWP.CharacterStylePropertiesArchive\x12>\n\x0fpara_properties\x18\x02 \x01(\x0b\x32%.TSWP.ParagraphStylePropertiesArchive\"\xa2\x02\n\x1a\x43ommandApplyFillSetArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12#\n\nchart_type\x18\x02 \x02(\x0e\x32\x0f.TSCH.ChartType\x12+\n\x08\x66ill_set\x18\x03 \x02(\x0b\x32\x19.TSCH.ChartFillSetArchive\x12/\n\x0cold_fill_set\x18\x04 \x01(\x0b\x32\x19.TSCH.ChartFillSetArchive\x12\x31\n)prior_last_applied_fill_set_lookup_string\x18\x05 \x01(\t\x12$\n\x0crollback_cmd\x18\x06 \x01(\x0b\x32\x0e.TSP.Reference\"~\n\x1b\x43ommandSetSeriesNameArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x13\n\x0bseriesIndex\x18\x02 \x02(\r\x12\x0f\n\x07oldName\x18\x03 \x01(\t\x12\x0f\n\x07newName\x18\x04 \x02(\t\"\x9c\x01\n\x1d\x43ommandSetCategoryNameArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x15\n\rcategoryIndex\x18\x02 \x02(\r\x12\x0f\n\x07oldName\x18\x03 \x01(\t\x12\x0f\n\x07newName\x18\x04 \x02(\t\x12\x18\n\x10isMultiDataIndex\x18\x05 \x01(\x08\"\xeb\x01\n\x19\x43ommandAddGridRowsArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x19\n\x06row_id\x18\x02 \x01(\x0b\x32\t.TSP.UUID\x12\x1e\n\x0brow_id_list\x18\x03 \x03(\x0b\x32\t.TSP.UUID\x12\x15\n\rrow_name_list\x18\x04 \x03(\t\x12)\n\x16undo_deletion_start_id\x18\x05 \x01(\x0b\x32\t.TSP.UUID\x12\'\n\x14undo_deletion_end_id\x18\x06 \x01(\x0b\x32\t.TSP.UUID\"\xf7\x01\n\x1c\x43ommandAddGridColumnsArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x1c\n\tcolumn_id\x18\x02 \x01(\x0b\x32\t.TSP.UUID\x12!\n\x0e\x63olumn_id_list\x18\x03 \x03(\x0b\x32\t.TSP.UUID\x12\x18\n\x10\x63olumn_name_list\x18\x04 \x03(\t\x12)\n\x16undo_deletion_start_id\x18\x05 \x01(\x0b\x32\t.TSP.UUID\x12\'\n\x14undo_deletion_end_id\x18\x06 \x01(\x0b\x32\t.TSP.UUID\"\xcd\x01\n\x1a\x43ommandMoveGridRowsArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x1f\n\x0cstart_row_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\x1d\n\nend_row_id\x18\x03 \x02(\x0b\x32\t.TSP.UUID\x12\x1f\n\x0c\x61\x66ter_row_id\x18\x04 \x01(\x0b\x32\t.TSP.UUID\x12$\n\x11undo_after_row_id\x18\x05 \x01(\x0b\x32\t.TSP.UUID\"\xdc\x01\n\x1d\x43ommandMoveGridColumnsArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\"\n\x0fstart_column_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12 \n\rend_column_id\x18\x03 \x02(\x0b\x32\t.TSP.UUID\x12\"\n\x0f\x61\x66ter_column_id\x18\x04 \x01(\x0b\x32\t.TSP.UUID\x12\'\n\x14undo_after_column_id\x18\x05 \x01(\x0b\x32\t.TSP.UUID\"\x9e\x03\n\x1c\x43ommandDeleteGridRowsArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x1f\n\x0cstart_row_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12\x1d\n\nend_row_id\x18\x03 \x02(\x0b\x32\t.TSP.UUID\x12\x15\n\rcut_row_names\x18\x04 \x03(\t\x12!\n\ncut_values\x18\x05 \x03(\x0b\x32\r.TSCH.GridRow\x12\x1c\n\x14undo_discards_values\x18\x06 \x01(\x08\x12+\n\x18undo_column_insertion_id\x18\x07 \x01(\x0b\x32\t.TSP.UUID\x12(\n\x15undo_row_insertion_id\x18\x08 \x01(\x0b\x32\t.TSP.UUID\x12#\n\x10undo_row_id_list\x18\t \x03(\x0b\x32\t.TSP.UUID\x12\x18\n\x10\x63ut_column_names\x18\x0b \x03(\t\x12&\n\x13undo_column_id_list\x18\x0c \x03(\x0b\x32\t.TSP.UUID\"\xa0\x03\n\x1f\x43ommandDeleteGridColumnsArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\"\n\x0fstart_column_id\x18\x02 \x02(\x0b\x32\t.TSP.UUID\x12 \n\rend_column_id\x18\x03 \x02(\x0b\x32\t.TSP.UUID\x12\x11\n\tcut_names\x18\x04 \x03(\t\x12!\n\ncut_values\x18\x05 \x03(\x0b\x32\r.TSCH.GridRow\x12\x1c\n\x14undo_discards_values\x18\x06 \x01(\x08\x12+\n\x18undo_column_insertion_id\x18\x07 \x01(\x0b\x32\t.TSP.UUID\x12(\n\x15undo_row_insertion_id\x18\x08 \x01(\x0b\x32\t.TSP.UUID\x12&\n\x13undo_column_id_list\x18\t \x03(\x0b\x32\t.TSP.UUID\x12\x15\n\rcut_row_names\x18\x0b \x03(\t\x12#\n\x10undo_row_id_list\x18\x0c \x03(\x0b\x32\t.TSP.UUID\"\x91\x01\n\x1a\x43ommandSetGridValueArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x10\n\x08rowindex\x18\x02 \x02(\r\x12\x13\n\x0b\x63olumnindex\x18\x03 \x02(\r\x12\x10\n\x08oldvalue\x18\x04 \x02(\x01\x12\x10\n\x08newvalue\x18\x05 \x02(\x01\"x\n\x1e\x43ommandSetGridDirectionArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x15\n\rold_direction\x18\x02 \x02(\r\x12\x15\n\rnew_direction\x18\x03 \x02(\r\"~\n\x1b\x43ommandSetSeriesTypeArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x13\n\x0bseriesindex\x18\x02 \x02(\r\x12\x0f\n\x07oldtype\x18\x03 \x02(\r\x12\x0f\n\x07newtype\x18\x04 \x02(\r\"p\n\x1e\x43ommandSetScatterFormatArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x11\n\toldformat\x18\x03 \x02(\r\x12\x11\n\tnewformat\x18\x04 \x02(\r\"r\n\"CommandSetMultiDataSetIndexArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x10\n\x08oldindex\x18\x02 \x02(\r\x12\x10\n\x08newindex\x18\x03 \x02(\r\"\xa2\x01\n\x1c\x43ommandSetLegendFrameArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12+\n\x10old_legend_frame\x18\x02 \x02(\x0b\x32\x11.TSCH.RectArchive\x12+\n\x10new_legend_frame\x18\x03 \x02(\x0b\x32\x11.TSCH.RectArchive\"\xd9\x01\n\x1b\x43ommandSetPieWedgeExplosion\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12\x16\n\x0eseries_indices\x18\x02 \x03(\r\x12\x18\n\x10wedge_explosions\x18\x03 \x03(\x01\x12\x1a\n\x12old_series_indices\x18\x05 \x03(\r\x12\x1c\n\x14old_wedge_explosions\x18\x06 \x03(\x01\x12$\n\x0crollback_cmd\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\"\xaf\x01\n\x16\x43ommandChartApplyTheme\x12\x31\n\x05super\x18\x01 \x02(\x0b\x32\".TSS.ApplyThemeChildCommandArchive\x12\x1c\n\x04info\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12$\n\x0cswap_command\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x06preset\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\"\xd1\x03\n\x17\x43ommandChartApplyPreset\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12+\n\x08\x62\x65havior\x18\x02 \x01(\x0e\x32\x19.TSCH.ApplyPresetBehavior\x12\x1e\n\x06preset\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\"\n\nold_preset\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12 \n\x18should_apply_swap_tuples\x18\x05 \x01(\x08\x12\x1d\n\x15\x61re_swap_tuples_valid\x18\x06 \x01(\x08\x12\x34\n\x0bswap_tuples\x18\x07 \x03(\x0b\x32\x1f.TSCH.StyleSwapUndoTupleArchive\x12<\n\x13inverse_swap_tuples\x18\x08 \x03(\x0b\x32\x1f.TSCH.StyleSwapUndoTupleArchive\x12\'\n\x0frollback_preset\x18\t \x01(\x0b\x32\x0e.TSP.Reference\x12=\n\x14rollback_swap_tuples\x18\n \x03(\x0b\x32\x1f.TSCH.StyleSwapUndoTupleArchive\"\xdc\x01\n\x1d\x43ommandCleanupGeometryArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12-\n\x15info_geometry_command\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x31\n\x19\x61nchor_attachment_command\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12/\n\x14original_legend_rect\x18\x04 \x01(\x0b\x32\x11.TSCH.RectArchive\"\xc8\x01\n\x13\x43hartCommandArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\"\n\nchart_info\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1c\n\x14original_dirty_state\x18\x03 \x01(\x08\x12)\n\x12\x63hart_info_id_path\x18\x04 \x01(\x0b\x32\r.TSP.UUIDPath\x12 \n\x18is_for_forward_undo_redo\x18\x05 \x01(\x08\"\x90\x04\n\x1f\x43ommandReplaceGridValuesArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12$\n\rold_data_rows\x18\x04 \x03(\x0b\x32\r.TSCH.GridRow\x12$\n\rnew_data_rows\x18\x05 \x03(\x0b\x32\r.TSCH.GridRow\x12\x15\n\rold_row_names\x18\x06 \x03(\t\x12\x15\n\rnew_row_names\x18\x07 \x03(\t\x12\x15\n\rold_col_names\x18\x08 \x03(\t\x12\x15\n\rnew_col_names\x18\t \x03(\t\x12#\n\x10update_row_uuids\x18\n \x03(\x0b\x32\t.TSP.UUID\x12&\n\x13update_column_uuids\x18\x0b \x03(\x0b\x32\t.TSP.UUID\x12 \n\radd_row_uuids\x18\x0c \x03(\x0b\x32\t.TSP.UUID\x12#\n\x10\x61\x64\x64_column_uuids\x18\r \x03(\x0b\x32\t.TSP.UUID\x12#\n\x10\x64\x65lete_row_uuids\x18\x0e \x03(\x0b\x32\t.TSP.UUID\x12&\n\x13\x64\x65lete_column_uuids\x18\x0f \x03(\x0b\x32\t.TSP.UUID\x12\x1c\n\x14set_series_direction\x18\x10 \x01(\x08\x12\x1c\n\x14new_series_direction\x18\x11 \x01(\r\"\xe8\x02\n CommandReplaceThemePresetArchive\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\x12\x1d\n\x05theme\x18\x02 \x02(\x0b\x32\x0e.TSP.Reference\x12\"\n\nold_preset\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\x12\"\n\nnew_preset\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12R\n\x0bidentifiers\x18\x05 \x03(\x0b\x32=.TSCH.CommandReplaceThemePresetArchive.StyleAndIdentifierPair\x12\x18\n\x10old_preset_index\x18\x06 \x01(\x04\x1aK\n\x16StyleAndIdentifierPair\x12\x1d\n\x05style\x18\x01 \x02(\x0b\x32\x0e.TSP.Reference\x12\x12\n\nidentifier\x18\x02 \x02(\t\"?\n\x19\x43ommandInvalidateWPCaches\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\"\xc4\x04\n!CommandReplaceCustomFormatArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12$\n\x0crollback_cmd\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12\x33\n\x11old_format_object\x18\x03 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12\x33\n\x11new_format_object\x18\x04 \x01(\x0b\x32\x18.TSK.FormatStructArchive\x12W\n\x11\x66orward_mutations\x18\x05 \x03(\x0b\x32<.TSCH.CommandReplaceCustomFormatArchive.FormatObjectMutation\x12W\n\x11reverse_mutations\x18\x06 \x03(\x0b\x32<.TSCH.CommandReplaceCustomFormatArchive.FormatObjectMutation\x1a\xb2\x01\n\x14\x46ormatObjectMutation\x12.\n\x10style_owner_type\x18\x01 \x01(\x0e\x32\x14.TSCH.StyleOwnerType\x12\x19\n\x11style_owner_index\x18\x02 \x01(\r\x12\x1e\n\x16\x66ormat_object_property\x18\x03 \x01(\r\x12/\n\rformat_object\x18\x04 \x01(\x0b\x32\x18.TSK.FormatStructArchive\"\xa5\x02\n\x1e\x43ommandAddReferenceLineArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12)\n\x07\x61xis_id\x18\x02 \x02(\x0b\x32\x18.TSCH.ChartAxisIDArchive\x12\x17\n\x04uuid\x18\x03 \x01(\x0b\x32\t.TSP.UUID\x12!\n\tnon_style\x18\x04 \x02(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x05style\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12(\n\x10paragraph_styles\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12)\n\x11rollback_commands\x18\x07 \x03(\x0b\x32\x0e.TSP.Reference\"\xa9\x02\n!CommandDeleteReferenceLineArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12)\n\x07\x61xis_id\x18\x02 \x02(\x0b\x32\x18.TSCH.ChartAxisIDArchive\x12\x17\n\x04uuid\x18\x03 \x02(\x0b\x32\t.TSP.UUID\x12!\n\tnon_style\x18\x04 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1d\n\x05style\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12(\n\x10paragraph_styles\x18\x06 \x03(\x0b\x32\x0e.TSP.Reference\x12*\n\x12style_swap_command\x18\x07 \x01(\x0b\x32\x0e.TSP.Reference\"\xe2\x02\n\x18\x43ommandPasteStyleArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12*\n\x12style_swap_command\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12M\n\x19inverse_chart_style_state\x18\x03 \x01(\x0b\x32*.TSCH.PropertyValueStorageContainerArchive\x12\x45\n\x11\x63hart_style_state\x18\x04 \x01(\x0b\x32*.TSCH.PropertyValueStorageContainerArchive\x12#\n\x0bshape_style\x18\x05 \x01(\x0b\x32\x0e.TSP.Reference\x12\x35\n\x0csubselection\x18\x06 \x03(\x0b\x32\x1f.TSCH.ChartSelectionPathArchive\"\x8c\x02\n\x1e\x43ommandReplaceImageDataArchive\x12(\n\x05super\x18\x01 \x02(\x0b\x32\x19.TSCH.ChartCommandArchive\x12*\n\x12style_swap_command\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12M\n\x19inverse_chart_style_state\x18\x03 \x01(\x0b\x32*.TSCH.PropertyValueStorageContainerArchive\x12\x45\n\x11\x63hart_style_state\x18\x04 \x01(\x0b\x32*.TSCH.PropertyValueStorageContainerArchive\"D\n\x1e\x43ommandInducedReplaceChartGrid\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\"C\n\x1d\x43ommandInduced3DChartGeometry\x12\"\n\x05super\x18\x01 \x02(\x0b\x32\x13.TSK.CommandArchive\"I\n$ChartTextSelectionTransformerArchive\x12!\n\tselection\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\"c\n(ChartDrawableSelectionTransformerArchive\x12\x37\n\x05super\x18\x01 \x02(\x0b\x32(.TSD.DrawableSelectionTransformerArchive\"N\n)ChartSubselectionTransformerHelperArchive\x12!\n\tselection\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\"\xa4\x01\n0ChartRefLineSubselectionTransformerHelperArchive\x12>\n\x05super\x18\x01 \x02(\x0b\x32/.TSCH.ChartSubselectionTransformerHelperArchive\x12\x30\n\x1dselected_reference_line_uuids\x18\x02 \x03(\x0b\x32\t.TSP.UUID\"s\n1ChartSubselectionIdentityTransformerHelperArchive\x12>\n\x05super\x18\x01 \x02(\x0b\x32/.TSCH.ChartSubselectionTransformerHelperArchive\"h\n#ChartSubselectionTransformerArchive\x12!\n\tselection\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference\x12\x1e\n\x06helper\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\"G\n\x1e\x43\x44\x45SelectionTransformerArchive\x12%\n\rcde_selection\x18\x01 \x01(\x0b\x32\x0e.TSP.Reference*h\n\x0eStyleOwnerType\x12\x0e\n\nchart_info\x10\x01\x12\x10\n\x0clegend_model\x10\x02\x12\x0e\n\nchart_axis\x10\x03\x12\x10\n\x0c\x63hart_series\x10\x04\x12\x12\n\x0ereference_line\x10\x05*\xf8\x02\n\rStyleSwapType\x12\x0f\n\x0b\x63hart_style\x10\x01\x12\x13\n\x0f\x63hart_non_style\x10\x02\x12\x10\n\x0clegend_style\x10\x03\x12\x14\n\x10legend_non_style\x10\x04\x12\x14\n\x10value_axis_style\x10\x05\x12\x18\n\x14value_axis_non_style\x10\x06\x12\x17\n\x13\x63\x61tegory_axis_style\x10\x07\x12\x1b\n\x17\x63\x61tegory_axis_non_style\x10\x08\x12\x16\n\x12series_theme_style\x10\t\x12\x18\n\x14series_private_style\x10\n\x12\x14\n\x10series_non_style\x10\x0b\x12\x13\n\x0fparagraph_style\x10\x0c\x12\x18\n\x14reference_line_style\x10\r\x12\x1c\n\x18reference_line_non_style\x10\x0e\x12\x1e\n\x1areference_line_theme_style\x10\x0f*\\\n\x13\x41pplyPresetBehavior\x12\x14\n\x10remove_overrides\x10\x01\x12\x16\n\x12preserve_overrides\x10\x02\x12\x17\n\x13preserve_appearance\x10\x03')
  ,
  dependencies=[TSCH3DArchives__pb2.DESCRIPTOR,TSCHArchives__Common__pb2.DESCRIPTOR,TSCHArchives__GEN__pb2.DESCRIPTOR,TSCHArchives__pb2.DESCRIPTOR,TSDArchives__pb2.DESCRIPTOR,TSDCommandArchives__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSPMessages__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSWPArchives__pb2.DESCRIPTOR,])

_STYLEOWNERTYPE = _descriptor.EnumDescriptor(
  name='StyleOwnerType',
  full_name='TSCH.StyleOwnerType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='chart_info', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='legend_model', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='chart_axis', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='chart_series', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='reference_line', index=4, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11811,
  serialized_end=11915,
)
_sym_db.RegisterEnumDescriptor(_STYLEOWNERTYPE)

StyleOwnerType = enum_type_wrapper.EnumTypeWrapper(_STYLEOWNERTYPE)
_STYLESWAPTYPE = _descriptor.EnumDescriptor(
  name='StyleSwapType',
  full_name='TSCH.StyleSwapType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='chart_style', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='chart_non_style', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='legend_style', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='legend_non_style', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='value_axis_style', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='value_axis_non_style', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='category_axis_style', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='category_axis_non_style', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='series_theme_style', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='series_private_style', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='series_non_style', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='paragraph_style', index=11, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='reference_line_style', index=12, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='reference_line_non_style', index=13, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='reference_line_theme_style', index=14, number=15,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11918,
  serialized_end=12294,
)
_sym_db.RegisterEnumDescriptor(_STYLESWAPTYPE)

StyleSwapType = enum_type_wrapper.EnumTypeWrapper(_STYLESWAPTYPE)
_APPLYPRESETBEHAVIOR = _descriptor.EnumDescriptor(
  name='ApplyPresetBehavior',
  full_name='TSCH.ApplyPresetBehavior',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='remove_overrides', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='preserve_overrides', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='preserve_appearance', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=12296,
  serialized_end=12388,
)
_sym_db.RegisterEnumDescriptor(_APPLYPRESETBEHAVIOR)

ApplyPresetBehavior = enum_type_wrapper.EnumTypeWrapper(_APPLYPRESETBEHAVIOR)
chart_info = 1
legend_model = 2
chart_axis = 3
chart_series = 4
reference_line = 5
chart_style = 1
chart_non_style = 2
legend_style = 3
legend_non_style = 4
value_axis_style = 5
value_axis_non_style = 6
category_axis_style = 7
category_axis_non_style = 8
series_theme_style = 9
series_private_style = 10
series_non_style = 11
paragraph_style = 12
reference_line_style = 13
reference_line_non_style = 14
reference_line_theme_style = 15
remove_overrides = 1
preserve_overrides = 2
preserve_appearance = 3



_STYLEOWNERPATH = _descriptor.Descriptor(
  name='StyleOwnerPath',
  full_name='TSCH.StyleOwnerPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuids', full_name='TSCH.StyleOwnerPath.uuids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=292,
)


_COMMANDSETCHARTTYPEARCHIVE = _descriptor.Descriptor(
  name='CommandSetChartTypeArchive',
  full_name='TSCH.CommandSetChartTypeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandSetChartTypeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_chart_type', full_name='TSCH.CommandSetChartTypeArchive.new_chart_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_chart_type', full_name='TSCH.CommandSetChartTypeArchive.old_chart_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_chart_type', full_name='TSCH.CommandSetChartTypeArchive.rollback_chart_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_ids', full_name='TSCH.CommandSetChartTypeArchive.row_ids', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_ids', full_name='TSCH.CommandSetChartTypeArchive.column_ids', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_row_ids', full_name='TSCH.CommandSetChartTypeArchive.old_row_ids', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_column_ids', full_name='TSCH.CommandSetChartTypeArchive.old_column_ids', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_row_ids', full_name='TSCH.CommandSetChartTypeArchive.rollback_row_ids', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_column_ids', full_name='TSCH.CommandSetChartTypeArchive.rollback_column_ids', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uses_captured_data', full_name='TSCH.CommandSetChartTypeArchive.uses_captured_data', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='use_default_data', full_name='TSCH.CommandSetChartTypeArchive.use_default_data', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=295,
  serialized_end=750,
)


_STYLESWAPUNDOTUPLEARCHIVE = _descriptor.Descriptor(
  name='StyleSwapUndoTupleArchive',
  full_name='TSCH.StyleSwapUndoTupleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chart_info', full_name='TSCH.StyleSwapUndoTupleArchive.chart_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='swap_type', full_name='TSCH.StyleSwapUndoTupleArchive.swap_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='TSCH.StyleSwapUndoTupleArchive.index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_value', full_name='TSCH.StyleSwapUndoTupleArchive.old_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_value', full_name='TSCH.StyleSwapUndoTupleArchive.new_value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ref_line_uuid', full_name='TSCH.StyleSwapUndoTupleArchive.ref_line_uuid', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=753,
  serialized_end=975,
)


_STYLESWAPUNDOTUPLESARCHIVE = _descriptor.Descriptor(
  name='StyleSwapUndoTuplesArchive',
  full_name='TSCH.StyleSwapUndoTuplesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='swap_tuples', full_name='TSCH.StyleSwapUndoTuplesArchive.swap_tuples', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=977,
  serialized_end=1059,
)


_COMMANDSTYLESWAPARCHIVE = _descriptor.Descriptor(
  name='CommandStyleSwapArchive',
  full_name='TSCH.CommandStyleSwapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandStyleSwapArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_tuples', full_name='TSCH.CommandStyleSwapArchive.undo_tuples', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1061,
  serialized_end=1182,
)


_COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP_GENERICMAPUNION = _descriptor.Descriptor(
  name='GenericMapUnion',
  full_name='TSCH.CommandMutatePropertiesArchive.GenericPropertyDeltaMap.GenericMapUnion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='chart_map', full_name='TSCH.CommandMutatePropertiesArchive.GenericPropertyDeltaMap.GenericMapUnion.chart_map', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legend_map', full_name='TSCH.CommandMutatePropertiesArchive.GenericPropertyDeltaMap.GenericMapUnion.legend_map', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis_map', full_name='TSCH.CommandMutatePropertiesArchive.GenericPropertyDeltaMap.GenericMapUnion.axis_map', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_map', full_name='TSCH.CommandMutatePropertiesArchive.GenericPropertyDeltaMap.GenericMapUnion.series_map', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_line_map', full_name='TSCH.CommandMutatePropertiesArchive.GenericPropertyDeltaMap.GenericMapUnion.reference_line_map', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1794,
  serialized_end=2175,
)

_COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP = _descriptor.Descriptor(
  name='GenericPropertyDeltaMap',
  full_name='TSCH.CommandMutatePropertiesArchive.GenericPropertyDeltaMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='style_owner_path', full_name='TSCH.CommandMutatePropertiesArchive.GenericPropertyDeltaMap.style_owner_path', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward_map', full_name='TSCH.CommandMutatePropertiesArchive.GenericPropertyDeltaMap.forward_map', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reverse_map', full_name='TSCH.CommandMutatePropertiesArchive.GenericPropertyDeltaMap.reverse_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP_GENERICMAPUNION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1520,
  serialized_end=2175,
)

_COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP_PARAGRAPHSTYLEPROPERTYMAPARCHIVE = _descriptor.Descriptor(
  name='ParagraphStylePropertyMapArchive',
  full_name='TSCH.CommandMutatePropertiesArchive.ParagraphStyleDeltaMap.ParagraphStylePropertyMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='char_properties', full_name='TSCH.CommandMutatePropertiesArchive.ParagraphStyleDeltaMap.ParagraphStylePropertyMapArchive.char_properties', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='para_properties', full_name='TSCH.CommandMutatePropertiesArchive.ParagraphStyleDeltaMap.ParagraphStylePropertyMapArchive.para_properties', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2523,
  serialized_end=2685,
)

_COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP = _descriptor.Descriptor(
  name='ParagraphStyleDeltaMap',
  full_name='TSCH.CommandMutatePropertiesArchive.ParagraphStyleDeltaMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='style_owner_path', full_name='TSCH.CommandMutatePropertiesArchive.ParagraphStyleDeltaMap.style_owner_path', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_style_index_property', full_name='TSCH.CommandMutatePropertiesArchive.ParagraphStyleDeltaMap.paragraph_style_index_property', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward_map', full_name='TSCH.CommandMutatePropertiesArchive.ParagraphStyleDeltaMap.forward_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reverse_map', full_name='TSCH.CommandMutatePropertiesArchive.ParagraphStyleDeltaMap.reverse_map', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP_PARAGRAPHSTYLEPROPERTYMAPARCHIVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2178,
  serialized_end=2685,
)

_COMMANDMUTATEPROPERTIESARCHIVE = _descriptor.Descriptor(
  name='CommandMutatePropertiesArchive',
  full_name='TSCH.CommandMutatePropertiesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandMutatePropertiesArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_cmd', full_name='TSCH.CommandMutatePropertiesArchive.rollback_cmd', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generic_property_delta_maps', full_name='TSCH.CommandMutatePropertiesArchive.generic_property_delta_maps', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_style_delta_maps', full_name='TSCH.CommandMutatePropertiesArchive.paragraph_style_delta_maps', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initiatedOnWeb', full_name='TSCH.CommandMutatePropertiesArchive.initiatedOnWeb', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP, _COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1185,
  serialized_end=2685,
)


_COMMANDSCALEALLTEXTARCHIVE = _descriptor.Descriptor(
  name='CommandScaleAllTextArchive',
  full_name='TSCH.CommandScaleAllTextArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandScaleAllTextArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_cmd', full_name='TSCH.CommandScaleAllTextArchive.rollback_cmd', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scale_factor', full_name='TSCH.CommandScaleAllTextArchive.scale_factor', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2688,
  serialized_end=2818,
)


_COMMANDSETFONTFAMILYARCHIVE_STYLESEMANTICTAG = _descriptor.Descriptor(
  name='StyleSemanticTag',
  full_name='TSCH.CommandSetFontFamilyArchive.StyleSemanticTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='swap_type', full_name='TSCH.CommandSetFontFamilyArchive.StyleSemanticTag.swap_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='TSCH.CommandSetFontFamilyArchive.StyleSemanticTag.index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3123,
  serialized_end=3196,
)

_COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP_PARAGRAPHSTYLEPROPERTYMAPARCHIVE = _descriptor.Descriptor(
  name='ParagraphStylePropertyMapArchive',
  full_name='TSCH.CommandSetFontFamilyArchive.SemanticParagraphStyleMutationMap.ParagraphStylePropertyMapArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='char_properties', full_name='TSCH.CommandSetFontFamilyArchive.SemanticParagraphStyleMutationMap.ParagraphStylePropertyMapArchive.char_properties', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='para_properties', full_name='TSCH.CommandSetFontFamilyArchive.SemanticParagraphStyleMutationMap.ParagraphStylePropertyMapArchive.para_properties', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2523,
  serialized_end=2685,
)

_COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP = _descriptor.Descriptor(
  name='SemanticParagraphStyleMutationMap',
  full_name='TSCH.CommandSetFontFamilyArchive.SemanticParagraphStyleMutationMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='style_semantic_tag', full_name='TSCH.CommandSetFontFamilyArchive.SemanticParagraphStyleMutationMap.style_semantic_tag', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_style_index_property', full_name='TSCH.CommandSetFontFamilyArchive.SemanticParagraphStyleMutationMap.paragraph_style_index_property', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward_map', full_name='TSCH.CommandSetFontFamilyArchive.SemanticParagraphStyleMutationMap.forward_map', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reverse_map', full_name='TSCH.CommandSetFontFamilyArchive.SemanticParagraphStyleMutationMap.reverse_map', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP_PARAGRAPHSTYLEPROPERTYMAPARCHIVE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3199,
  serialized_end=3765,
)

_COMMANDSETFONTFAMILYARCHIVE = _descriptor.Descriptor(
  name='CommandSetFontFamilyArchive',
  full_name='TSCH.CommandSetFontFamilyArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandSetFontFamilyArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_cmd', full_name='TSCH.CommandSetFontFamilyArchive.rollback_cmd', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_font_family', full_name='TSCH.CommandSetFontFamilyArchive.new_font_family', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_font_family', full_name='TSCH.CommandSetFontFamilyArchive.old_font_family', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_style_delta_maps', full_name='TSCH.CommandSetFontFamilyArchive.paragraph_style_delta_maps', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_bold', full_name='TSCH.CommandSetFontFamilyArchive.is_bold', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_italic', full_name='TSCH.CommandSetFontFamilyArchive.is_italic', index=6,
      number=7, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COMMANDSETFONTFAMILYARCHIVE_STYLESEMANTICTAG, _COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2821,
  serialized_end=3765,
)


_COMMANDAPPLYFILLSETARCHIVE = _descriptor.Descriptor(
  name='CommandApplyFillSetArchive',
  full_name='TSCH.CommandApplyFillSetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandApplyFillSetArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chart_type', full_name='TSCH.CommandApplyFillSetArchive.chart_type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fill_set', full_name='TSCH.CommandApplyFillSetArchive.fill_set', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_fill_set', full_name='TSCH.CommandApplyFillSetArchive.old_fill_set', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='prior_last_applied_fill_set_lookup_string', full_name='TSCH.CommandApplyFillSetArchive.prior_last_applied_fill_set_lookup_string', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_cmd', full_name='TSCH.CommandApplyFillSetArchive.rollback_cmd', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3768,
  serialized_end=4058,
)


_COMMANDSETSERIESNAMEARCHIVE = _descriptor.Descriptor(
  name='CommandSetSeriesNameArchive',
  full_name='TSCH.CommandSetSeriesNameArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandSetSeriesNameArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seriesIndex', full_name='TSCH.CommandSetSeriesNameArchive.seriesIndex', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldName', full_name='TSCH.CommandSetSeriesNameArchive.oldName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newName', full_name='TSCH.CommandSetSeriesNameArchive.newName', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4060,
  serialized_end=4186,
)


_COMMANDSETCATEGORYNAMEARCHIVE = _descriptor.Descriptor(
  name='CommandSetCategoryNameArchive',
  full_name='TSCH.CommandSetCategoryNameArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandSetCategoryNameArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='categoryIndex', full_name='TSCH.CommandSetCategoryNameArchive.categoryIndex', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldName', full_name='TSCH.CommandSetCategoryNameArchive.oldName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newName', full_name='TSCH.CommandSetCategoryNameArchive.newName', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isMultiDataIndex', full_name='TSCH.CommandSetCategoryNameArchive.isMultiDataIndex', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4189,
  serialized_end=4345,
)


_COMMANDADDGRIDROWSARCHIVE = _descriptor.Descriptor(
  name='CommandAddGridRowsArchive',
  full_name='TSCH.CommandAddGridRowsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandAddGridRowsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_id', full_name='TSCH.CommandAddGridRowsArchive.row_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_id_list', full_name='TSCH.CommandAddGridRowsArchive.row_id_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row_name_list', full_name='TSCH.CommandAddGridRowsArchive.row_name_list', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_deletion_start_id', full_name='TSCH.CommandAddGridRowsArchive.undo_deletion_start_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_deletion_end_id', full_name='TSCH.CommandAddGridRowsArchive.undo_deletion_end_id', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4348,
  serialized_end=4583,
)


_COMMANDADDGRIDCOLUMNSARCHIVE = _descriptor.Descriptor(
  name='CommandAddGridColumnsArchive',
  full_name='TSCH.CommandAddGridColumnsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandAddGridColumnsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_id', full_name='TSCH.CommandAddGridColumnsArchive.column_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_id_list', full_name='TSCH.CommandAddGridColumnsArchive.column_id_list', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column_name_list', full_name='TSCH.CommandAddGridColumnsArchive.column_name_list', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_deletion_start_id', full_name='TSCH.CommandAddGridColumnsArchive.undo_deletion_start_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_deletion_end_id', full_name='TSCH.CommandAddGridColumnsArchive.undo_deletion_end_id', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4586,
  serialized_end=4833,
)


_COMMANDMOVEGRIDROWSARCHIVE = _descriptor.Descriptor(
  name='CommandMoveGridRowsArchive',
  full_name='TSCH.CommandMoveGridRowsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandMoveGridRowsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_row_id', full_name='TSCH.CommandMoveGridRowsArchive.start_row_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_row_id', full_name='TSCH.CommandMoveGridRowsArchive.end_row_id', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='after_row_id', full_name='TSCH.CommandMoveGridRowsArchive.after_row_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_after_row_id', full_name='TSCH.CommandMoveGridRowsArchive.undo_after_row_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4836,
  serialized_end=5041,
)


_COMMANDMOVEGRIDCOLUMNSARCHIVE = _descriptor.Descriptor(
  name='CommandMoveGridColumnsArchive',
  full_name='TSCH.CommandMoveGridColumnsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandMoveGridColumnsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_column_id', full_name='TSCH.CommandMoveGridColumnsArchive.start_column_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_column_id', full_name='TSCH.CommandMoveGridColumnsArchive.end_column_id', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='after_column_id', full_name='TSCH.CommandMoveGridColumnsArchive.after_column_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_after_column_id', full_name='TSCH.CommandMoveGridColumnsArchive.undo_after_column_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5044,
  serialized_end=5264,
)


_COMMANDDELETEGRIDROWSARCHIVE = _descriptor.Descriptor(
  name='CommandDeleteGridRowsArchive',
  full_name='TSCH.CommandDeleteGridRowsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandDeleteGridRowsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_row_id', full_name='TSCH.CommandDeleteGridRowsArchive.start_row_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_row_id', full_name='TSCH.CommandDeleteGridRowsArchive.end_row_id', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cut_row_names', full_name='TSCH.CommandDeleteGridRowsArchive.cut_row_names', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cut_values', full_name='TSCH.CommandDeleteGridRowsArchive.cut_values', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_discards_values', full_name='TSCH.CommandDeleteGridRowsArchive.undo_discards_values', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_column_insertion_id', full_name='TSCH.CommandDeleteGridRowsArchive.undo_column_insertion_id', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_row_insertion_id', full_name='TSCH.CommandDeleteGridRowsArchive.undo_row_insertion_id', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_row_id_list', full_name='TSCH.CommandDeleteGridRowsArchive.undo_row_id_list', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cut_column_names', full_name='TSCH.CommandDeleteGridRowsArchive.cut_column_names', index=9,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_column_id_list', full_name='TSCH.CommandDeleteGridRowsArchive.undo_column_id_list', index=10,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5267,
  serialized_end=5681,
)


_COMMANDDELETEGRIDCOLUMNSARCHIVE = _descriptor.Descriptor(
  name='CommandDeleteGridColumnsArchive',
  full_name='TSCH.CommandDeleteGridColumnsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandDeleteGridColumnsArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_column_id', full_name='TSCH.CommandDeleteGridColumnsArchive.start_column_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_column_id', full_name='TSCH.CommandDeleteGridColumnsArchive.end_column_id', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cut_names', full_name='TSCH.CommandDeleteGridColumnsArchive.cut_names', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cut_values', full_name='TSCH.CommandDeleteGridColumnsArchive.cut_values', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_discards_values', full_name='TSCH.CommandDeleteGridColumnsArchive.undo_discards_values', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_column_insertion_id', full_name='TSCH.CommandDeleteGridColumnsArchive.undo_column_insertion_id', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_row_insertion_id', full_name='TSCH.CommandDeleteGridColumnsArchive.undo_row_insertion_id', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_column_id_list', full_name='TSCH.CommandDeleteGridColumnsArchive.undo_column_id_list', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cut_row_names', full_name='TSCH.CommandDeleteGridColumnsArchive.cut_row_names', index=9,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undo_row_id_list', full_name='TSCH.CommandDeleteGridColumnsArchive.undo_row_id_list', index=10,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5684,
  serialized_end=6100,
)


_COMMANDSETGRIDVALUEARCHIVE = _descriptor.Descriptor(
  name='CommandSetGridValueArchive',
  full_name='TSCH.CommandSetGridValueArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandSetGridValueArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rowindex', full_name='TSCH.CommandSetGridValueArchive.rowindex', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='columnindex', full_name='TSCH.CommandSetGridValueArchive.columnindex', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldvalue', full_name='TSCH.CommandSetGridValueArchive.oldvalue', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newvalue', full_name='TSCH.CommandSetGridValueArchive.newvalue', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6103,
  serialized_end=6248,
)


_COMMANDSETGRIDDIRECTIONARCHIVE = _descriptor.Descriptor(
  name='CommandSetGridDirectionArchive',
  full_name='TSCH.CommandSetGridDirectionArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandSetGridDirectionArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_direction', full_name='TSCH.CommandSetGridDirectionArchive.old_direction', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_direction', full_name='TSCH.CommandSetGridDirectionArchive.new_direction', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6250,
  serialized_end=6370,
)


_COMMANDSETSERIESTYPEARCHIVE = _descriptor.Descriptor(
  name='CommandSetSeriesTypeArchive',
  full_name='TSCH.CommandSetSeriesTypeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandSetSeriesTypeArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seriesindex', full_name='TSCH.CommandSetSeriesTypeArchive.seriesindex', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldtype', full_name='TSCH.CommandSetSeriesTypeArchive.oldtype', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newtype', full_name='TSCH.CommandSetSeriesTypeArchive.newtype', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6372,
  serialized_end=6498,
)


_COMMANDSETSCATTERFORMATARCHIVE = _descriptor.Descriptor(
  name='CommandSetScatterFormatArchive',
  full_name='TSCH.CommandSetScatterFormatArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandSetScatterFormatArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldformat', full_name='TSCH.CommandSetScatterFormatArchive.oldformat', index=1,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newformat', full_name='TSCH.CommandSetScatterFormatArchive.newformat', index=2,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6500,
  serialized_end=6612,
)


_COMMANDSETMULTIDATASETINDEXARCHIVE = _descriptor.Descriptor(
  name='CommandSetMultiDataSetIndexArchive',
  full_name='TSCH.CommandSetMultiDataSetIndexArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandSetMultiDataSetIndexArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oldindex', full_name='TSCH.CommandSetMultiDataSetIndexArchive.oldindex', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='newindex', full_name='TSCH.CommandSetMultiDataSetIndexArchive.newindex', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6614,
  serialized_end=6728,
)


_COMMANDSETLEGENDFRAMEARCHIVE = _descriptor.Descriptor(
  name='CommandSetLegendFrameArchive',
  full_name='TSCH.CommandSetLegendFrameArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandSetLegendFrameArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_legend_frame', full_name='TSCH.CommandSetLegendFrameArchive.old_legend_frame', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_legend_frame', full_name='TSCH.CommandSetLegendFrameArchive.new_legend_frame', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6731,
  serialized_end=6893,
)


_COMMANDSETPIEWEDGEEXPLOSION = _descriptor.Descriptor(
  name='CommandSetPieWedgeExplosion',
  full_name='TSCH.CommandSetPieWedgeExplosion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandSetPieWedgeExplosion.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='series_indices', full_name='TSCH.CommandSetPieWedgeExplosion.series_indices', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wedge_explosions', full_name='TSCH.CommandSetPieWedgeExplosion.wedge_explosions', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_series_indices', full_name='TSCH.CommandSetPieWedgeExplosion.old_series_indices', index=3,
      number=5, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_wedge_explosions', full_name='TSCH.CommandSetPieWedgeExplosion.old_wedge_explosions', index=4,
      number=6, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_cmd', full_name='TSCH.CommandSetPieWedgeExplosion.rollback_cmd', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6896,
  serialized_end=7113,
)


_COMMANDCHARTAPPLYTHEME = _descriptor.Descriptor(
  name='CommandChartApplyTheme',
  full_name='TSCH.CommandChartApplyTheme',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandChartApplyTheme.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='TSCH.CommandChartApplyTheme.info', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='swap_command', full_name='TSCH.CommandChartApplyTheme.swap_command', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset', full_name='TSCH.CommandChartApplyTheme.preset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7116,
  serialized_end=7291,
)


_COMMANDCHARTAPPLYPRESET = _descriptor.Descriptor(
  name='CommandChartApplyPreset',
  full_name='TSCH.CommandChartApplyPreset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandChartApplyPreset.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='behavior', full_name='TSCH.CommandChartApplyPreset.behavior', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset', full_name='TSCH.CommandChartApplyPreset.preset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_preset', full_name='TSCH.CommandChartApplyPreset.old_preset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='should_apply_swap_tuples', full_name='TSCH.CommandChartApplyPreset.should_apply_swap_tuples', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='are_swap_tuples_valid', full_name='TSCH.CommandChartApplyPreset.are_swap_tuples_valid', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='swap_tuples', full_name='TSCH.CommandChartApplyPreset.swap_tuples', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_swap_tuples', full_name='TSCH.CommandChartApplyPreset.inverse_swap_tuples', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_preset', full_name='TSCH.CommandChartApplyPreset.rollback_preset', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_swap_tuples', full_name='TSCH.CommandChartApplyPreset.rollback_swap_tuples', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7294,
  serialized_end=7759,
)


_COMMANDCLEANUPGEOMETRYARCHIVE = _descriptor.Descriptor(
  name='CommandCleanupGeometryArchive',
  full_name='TSCH.CommandCleanupGeometryArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandCleanupGeometryArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info_geometry_command', full_name='TSCH.CommandCleanupGeometryArchive.info_geometry_command', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='anchor_attachment_command', full_name='TSCH.CommandCleanupGeometryArchive.anchor_attachment_command', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_legend_rect', full_name='TSCH.CommandCleanupGeometryArchive.original_legend_rect', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7762,
  serialized_end=7982,
)


_CHARTCOMMANDARCHIVE = _descriptor.Descriptor(
  name='ChartCommandArchive',
  full_name='TSCH.ChartCommandArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartCommandArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chart_info', full_name='TSCH.ChartCommandArchive.chart_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_dirty_state', full_name='TSCH.ChartCommandArchive.original_dirty_state', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chart_info_id_path', full_name='TSCH.ChartCommandArchive.chart_info_id_path', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='is_for_forward_undo_redo', full_name='TSCH.ChartCommandArchive.is_for_forward_undo_redo', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7985,
  serialized_end=8185,
)


_COMMANDREPLACEGRIDVALUESARCHIVE = _descriptor.Descriptor(
  name='CommandReplaceGridValuesArchive',
  full_name='TSCH.CommandReplaceGridValuesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandReplaceGridValuesArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_data_rows', full_name='TSCH.CommandReplaceGridValuesArchive.old_data_rows', index=1,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_data_rows', full_name='TSCH.CommandReplaceGridValuesArchive.new_data_rows', index=2,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_row_names', full_name='TSCH.CommandReplaceGridValuesArchive.old_row_names', index=3,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_row_names', full_name='TSCH.CommandReplaceGridValuesArchive.new_row_names', index=4,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_col_names', full_name='TSCH.CommandReplaceGridValuesArchive.old_col_names', index=5,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_col_names', full_name='TSCH.CommandReplaceGridValuesArchive.new_col_names', index=6,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_row_uuids', full_name='TSCH.CommandReplaceGridValuesArchive.update_row_uuids', index=7,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_column_uuids', full_name='TSCH.CommandReplaceGridValuesArchive.update_column_uuids', index=8,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='add_row_uuids', full_name='TSCH.CommandReplaceGridValuesArchive.add_row_uuids', index=9,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='add_column_uuids', full_name='TSCH.CommandReplaceGridValuesArchive.add_column_uuids', index=10,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_row_uuids', full_name='TSCH.CommandReplaceGridValuesArchive.delete_row_uuids', index=11,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_column_uuids', full_name='TSCH.CommandReplaceGridValuesArchive.delete_column_uuids', index=12,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='set_series_direction', full_name='TSCH.CommandReplaceGridValuesArchive.set_series_direction', index=13,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_series_direction', full_name='TSCH.CommandReplaceGridValuesArchive.new_series_direction', index=14,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8188,
  serialized_end=8716,
)


_COMMANDREPLACETHEMEPRESETARCHIVE_STYLEANDIDENTIFIERPAIR = _descriptor.Descriptor(
  name='StyleAndIdentifierPair',
  full_name='TSCH.CommandReplaceThemePresetArchive.StyleAndIdentifierPair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='style', full_name='TSCH.CommandReplaceThemePresetArchive.StyleAndIdentifierPair.style', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifier', full_name='TSCH.CommandReplaceThemePresetArchive.StyleAndIdentifierPair.identifier', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9004,
  serialized_end=9079,
)

_COMMANDREPLACETHEMEPRESETARCHIVE = _descriptor.Descriptor(
  name='CommandReplaceThemePresetArchive',
  full_name='TSCH.CommandReplaceThemePresetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandReplaceThemePresetArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='theme', full_name='TSCH.CommandReplaceThemePresetArchive.theme', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_preset', full_name='TSCH.CommandReplaceThemePresetArchive.old_preset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_preset', full_name='TSCH.CommandReplaceThemePresetArchive.new_preset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='identifiers', full_name='TSCH.CommandReplaceThemePresetArchive.identifiers', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_preset_index', full_name='TSCH.CommandReplaceThemePresetArchive.old_preset_index', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COMMANDREPLACETHEMEPRESETARCHIVE_STYLEANDIDENTIFIERPAIR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8719,
  serialized_end=9079,
)


_COMMANDINVALIDATEWPCACHES = _descriptor.Descriptor(
  name='CommandInvalidateWPCaches',
  full_name='TSCH.CommandInvalidateWPCaches',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandInvalidateWPCaches.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9081,
  serialized_end=9144,
)


_COMMANDREPLACECUSTOMFORMATARCHIVE_FORMATOBJECTMUTATION = _descriptor.Descriptor(
  name='FormatObjectMutation',
  full_name='TSCH.CommandReplaceCustomFormatArchive.FormatObjectMutation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='style_owner_type', full_name='TSCH.CommandReplaceCustomFormatArchive.FormatObjectMutation.style_owner_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_owner_index', full_name='TSCH.CommandReplaceCustomFormatArchive.FormatObjectMutation.style_owner_index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_object_property', full_name='TSCH.CommandReplaceCustomFormatArchive.FormatObjectMutation.format_object_property', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='format_object', full_name='TSCH.CommandReplaceCustomFormatArchive.FormatObjectMutation.format_object', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9549,
  serialized_end=9727,
)

_COMMANDREPLACECUSTOMFORMATARCHIVE = _descriptor.Descriptor(
  name='CommandReplaceCustomFormatArchive',
  full_name='TSCH.CommandReplaceCustomFormatArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandReplaceCustomFormatArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_cmd', full_name='TSCH.CommandReplaceCustomFormatArchive.rollback_cmd', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='old_format_object', full_name='TSCH.CommandReplaceCustomFormatArchive.old_format_object', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='new_format_object', full_name='TSCH.CommandReplaceCustomFormatArchive.new_format_object', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forward_mutations', full_name='TSCH.CommandReplaceCustomFormatArchive.forward_mutations', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reverse_mutations', full_name='TSCH.CommandReplaceCustomFormatArchive.reverse_mutations', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_COMMANDREPLACECUSTOMFORMATARCHIVE_FORMATOBJECTMUTATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9147,
  serialized_end=9727,
)


_COMMANDADDREFERENCELINEARCHIVE = _descriptor.Descriptor(
  name='CommandAddReferenceLineArchive',
  full_name='TSCH.CommandAddReferenceLineArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandAddReferenceLineArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis_id', full_name='TSCH.CommandAddReferenceLineArchive.axis_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='TSCH.CommandAddReferenceLineArchive.uuid', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='non_style', full_name='TSCH.CommandAddReferenceLineArchive.non_style', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='TSCH.CommandAddReferenceLineArchive.style', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_styles', full_name='TSCH.CommandAddReferenceLineArchive.paragraph_styles', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_commands', full_name='TSCH.CommandAddReferenceLineArchive.rollback_commands', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9730,
  serialized_end=10023,
)


_COMMANDDELETEREFERENCELINEARCHIVE = _descriptor.Descriptor(
  name='CommandDeleteReferenceLineArchive',
  full_name='TSCH.CommandDeleteReferenceLineArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandDeleteReferenceLineArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='axis_id', full_name='TSCH.CommandDeleteReferenceLineArchive.axis_id', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='TSCH.CommandDeleteReferenceLineArchive.uuid', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='non_style', full_name='TSCH.CommandDeleteReferenceLineArchive.non_style', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style', full_name='TSCH.CommandDeleteReferenceLineArchive.style', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='paragraph_styles', full_name='TSCH.CommandDeleteReferenceLineArchive.paragraph_styles', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_swap_command', full_name='TSCH.CommandDeleteReferenceLineArchive.style_swap_command', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10026,
  serialized_end=10323,
)


_COMMANDPASTESTYLEARCHIVE = _descriptor.Descriptor(
  name='CommandPasteStyleArchive',
  full_name='TSCH.CommandPasteStyleArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandPasteStyleArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_swap_command', full_name='TSCH.CommandPasteStyleArchive.style_swap_command', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_chart_style_state', full_name='TSCH.CommandPasteStyleArchive.inverse_chart_style_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chart_style_state', full_name='TSCH.CommandPasteStyleArchive.chart_style_state', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shape_style', full_name='TSCH.CommandPasteStyleArchive.shape_style', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subselection', full_name='TSCH.CommandPasteStyleArchive.subselection', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10326,
  serialized_end=10680,
)


_COMMANDREPLACEIMAGEDATAARCHIVE = _descriptor.Descriptor(
  name='CommandReplaceImageDataArchive',
  full_name='TSCH.CommandReplaceImageDataArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandReplaceImageDataArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_swap_command', full_name='TSCH.CommandReplaceImageDataArchive.style_swap_command', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inverse_chart_style_state', full_name='TSCH.CommandReplaceImageDataArchive.inverse_chart_style_state', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chart_style_state', full_name='TSCH.CommandReplaceImageDataArchive.chart_style_state', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10683,
  serialized_end=10951,
)


_COMMANDINDUCEDREPLACECHARTGRID = _descriptor.Descriptor(
  name='CommandInducedReplaceChartGrid',
  full_name='TSCH.CommandInducedReplaceChartGrid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandInducedReplaceChartGrid.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10953,
  serialized_end=11021,
)


_COMMANDINDUCED3DCHARTGEOMETRY = _descriptor.Descriptor(
  name='CommandInduced3DChartGeometry',
  full_name='TSCH.CommandInduced3DChartGeometry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.CommandInduced3DChartGeometry.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11023,
  serialized_end=11090,
)


_CHARTTEXTSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='ChartTextSelectionTransformerArchive',
  full_name='TSCH.ChartTextSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selection', full_name='TSCH.ChartTextSelectionTransformerArchive.selection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11092,
  serialized_end=11165,
)


_CHARTDRAWABLESELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='ChartDrawableSelectionTransformerArchive',
  full_name='TSCH.ChartDrawableSelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartDrawableSelectionTransformerArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11167,
  serialized_end=11266,
)


_CHARTSUBSELECTIONTRANSFORMERHELPERARCHIVE = _descriptor.Descriptor(
  name='ChartSubselectionTransformerHelperArchive',
  full_name='TSCH.ChartSubselectionTransformerHelperArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selection', full_name='TSCH.ChartSubselectionTransformerHelperArchive.selection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11268,
  serialized_end=11346,
)


_CHARTREFLINESUBSELECTIONTRANSFORMERHELPERARCHIVE = _descriptor.Descriptor(
  name='ChartRefLineSubselectionTransformerHelperArchive',
  full_name='TSCH.ChartRefLineSubselectionTransformerHelperArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartRefLineSubselectionTransformerHelperArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='selected_reference_line_uuids', full_name='TSCH.ChartRefLineSubselectionTransformerHelperArchive.selected_reference_line_uuids', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11349,
  serialized_end=11513,
)


_CHARTSUBSELECTIONIDENTITYTRANSFORMERHELPERARCHIVE = _descriptor.Descriptor(
  name='ChartSubselectionIdentityTransformerHelperArchive',
  full_name='TSCH.ChartSubselectionIdentityTransformerHelperArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='super', full_name='TSCH.ChartSubselectionIdentityTransformerHelperArchive.super', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11515,
  serialized_end=11630,
)


_CHARTSUBSELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='ChartSubselectionTransformerArchive',
  full_name='TSCH.ChartSubselectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='selection', full_name='TSCH.ChartSubselectionTransformerArchive.selection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='helper', full_name='TSCH.ChartSubselectionTransformerArchive.helper', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11632,
  serialized_end=11736,
)


_CDESELECTIONTRANSFORMERARCHIVE = _descriptor.Descriptor(
  name='CDESelectionTransformerArchive',
  full_name='TSCH.CDESelectionTransformerArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cde_selection', full_name='TSCH.CDESelectionTransformerArchive.cde_selection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11738,
  serialized_end=11809,
)

_STYLEOWNERPATH.fields_by_name['uuids'].message_type = TSPMessages__pb2._UUID
_COMMANDSETCHARTTYPEARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDSETCHARTTYPEARCHIVE.fields_by_name['new_chart_type'].enum_type = TSCHArchives__Common__pb2._CHARTTYPE
_COMMANDSETCHARTTYPEARCHIVE.fields_by_name['old_chart_type'].enum_type = TSCHArchives__Common__pb2._CHARTTYPE
_COMMANDSETCHARTTYPEARCHIVE.fields_by_name['rollback_chart_type'].enum_type = TSCHArchives__Common__pb2._CHARTTYPE
_COMMANDSETCHARTTYPEARCHIVE.fields_by_name['row_ids'].message_type = TSPMessages__pb2._UUID
_COMMANDSETCHARTTYPEARCHIVE.fields_by_name['column_ids'].message_type = TSPMessages__pb2._UUID
_COMMANDSETCHARTTYPEARCHIVE.fields_by_name['old_row_ids'].message_type = TSPMessages__pb2._UUID
_COMMANDSETCHARTTYPEARCHIVE.fields_by_name['old_column_ids'].message_type = TSPMessages__pb2._UUID
_COMMANDSETCHARTTYPEARCHIVE.fields_by_name['rollback_row_ids'].message_type = TSPMessages__pb2._UUID
_COMMANDSETCHARTTYPEARCHIVE.fields_by_name['rollback_column_ids'].message_type = TSPMessages__pb2._UUID
_STYLESWAPUNDOTUPLEARCHIVE.fields_by_name['chart_info'].message_type = TSPMessages__pb2._REFERENCE
_STYLESWAPUNDOTUPLEARCHIVE.fields_by_name['swap_type'].enum_type = _STYLESWAPTYPE
_STYLESWAPUNDOTUPLEARCHIVE.fields_by_name['old_value'].message_type = TSPMessages__pb2._REFERENCE
_STYLESWAPUNDOTUPLEARCHIVE.fields_by_name['new_value'].message_type = TSPMessages__pb2._REFERENCE
_STYLESWAPUNDOTUPLEARCHIVE.fields_by_name['ref_line_uuid'].message_type = TSPMessages__pb2._UUID
_STYLESWAPUNDOTUPLESARCHIVE.fields_by_name['swap_tuples'].message_type = _STYLESWAPUNDOTUPLEARCHIVE
_COMMANDSTYLESWAPARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDSTYLESWAPARCHIVE.fields_by_name['undo_tuples'].message_type = _STYLESWAPUNDOTUPLEARCHIVE
_COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP_GENERICMAPUNION.fields_by_name['chart_map'].message_type = TSCHArchives__GEN__pb2._CHARTGENERICPROPERTYMAPARCHIVE
_COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP_GENERICMAPUNION.fields_by_name['legend_map'].message_type = TSCHArchives__GEN__pb2._LEGENDGENERICPROPERTYMAPARCHIVE
_COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP_GENERICMAPUNION.fields_by_name['axis_map'].message_type = TSCHArchives__GEN__pb2._CHARTAXISGENERICPROPERTYMAPARCHIVE
_COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP_GENERICMAPUNION.fields_by_name['series_map'].message_type = TSCHArchives__GEN__pb2._CHARTSERIESGENERICPROPERTYMAPARCHIVE
_COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP_GENERICMAPUNION.fields_by_name['reference_line_map'].message_type = TSCHArchives__GEN__pb2._REFERENCELINEGENERICPROPERTYMAPARCHIVE
_COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP_GENERICMAPUNION.containing_type = _COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP
_COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP.fields_by_name['style_owner_path'].message_type = _STYLEOWNERPATH
_COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP.fields_by_name['forward_map'].message_type = _COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP_GENERICMAPUNION
_COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP.fields_by_name['reverse_map'].message_type = _COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP_GENERICMAPUNION
_COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP.containing_type = _COMMANDMUTATEPROPERTIESARCHIVE
_COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP_PARAGRAPHSTYLEPROPERTYMAPARCHIVE.fields_by_name['char_properties'].message_type = TSWPArchives__pb2._CHARACTERSTYLEPROPERTIESARCHIVE
_COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP_PARAGRAPHSTYLEPROPERTYMAPARCHIVE.fields_by_name['para_properties'].message_type = TSWPArchives__pb2._PARAGRAPHSTYLEPROPERTIESARCHIVE
_COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP_PARAGRAPHSTYLEPROPERTYMAPARCHIVE.containing_type = _COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP
_COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP.fields_by_name['style_owner_path'].message_type = _STYLEOWNERPATH
_COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP.fields_by_name['forward_map'].message_type = _COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP_PARAGRAPHSTYLEPROPERTYMAPARCHIVE
_COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP.fields_by_name['reverse_map'].message_type = _COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP_PARAGRAPHSTYLEPROPERTYMAPARCHIVE
_COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP.containing_type = _COMMANDMUTATEPROPERTIESARCHIVE
_COMMANDMUTATEPROPERTIESARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDMUTATEPROPERTIESARCHIVE.fields_by_name['rollback_cmd'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDMUTATEPROPERTIESARCHIVE.fields_by_name['generic_property_delta_maps'].message_type = _COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP
_COMMANDMUTATEPROPERTIESARCHIVE.fields_by_name['paragraph_style_delta_maps'].message_type = _COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP
_COMMANDSCALEALLTEXTARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDSCALEALLTEXTARCHIVE.fields_by_name['rollback_cmd'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETFONTFAMILYARCHIVE_STYLESEMANTICTAG.fields_by_name['swap_type'].enum_type = _STYLESWAPTYPE
_COMMANDSETFONTFAMILYARCHIVE_STYLESEMANTICTAG.containing_type = _COMMANDSETFONTFAMILYARCHIVE
_COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP_PARAGRAPHSTYLEPROPERTYMAPARCHIVE.fields_by_name['char_properties'].message_type = TSWPArchives__pb2._CHARACTERSTYLEPROPERTIESARCHIVE
_COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP_PARAGRAPHSTYLEPROPERTYMAPARCHIVE.fields_by_name['para_properties'].message_type = TSWPArchives__pb2._PARAGRAPHSTYLEPROPERTIESARCHIVE
_COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP_PARAGRAPHSTYLEPROPERTYMAPARCHIVE.containing_type = _COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP
_COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP.fields_by_name['style_semantic_tag'].message_type = _COMMANDSETFONTFAMILYARCHIVE_STYLESEMANTICTAG
_COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP.fields_by_name['forward_map'].message_type = _COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP_PARAGRAPHSTYLEPROPERTYMAPARCHIVE
_COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP.fields_by_name['reverse_map'].message_type = _COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP_PARAGRAPHSTYLEPROPERTYMAPARCHIVE
_COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP.containing_type = _COMMANDSETFONTFAMILYARCHIVE
_COMMANDSETFONTFAMILYARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDSETFONTFAMILYARCHIVE.fields_by_name['rollback_cmd'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETFONTFAMILYARCHIVE.fields_by_name['paragraph_style_delta_maps'].message_type = _COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP
_COMMANDAPPLYFILLSETARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDAPPLYFILLSETARCHIVE.fields_by_name['chart_type'].enum_type = TSCHArchives__Common__pb2._CHARTTYPE
_COMMANDAPPLYFILLSETARCHIVE.fields_by_name['fill_set'].message_type = TSCHArchives__pb2._CHARTFILLSETARCHIVE
_COMMANDAPPLYFILLSETARCHIVE.fields_by_name['old_fill_set'].message_type = TSCHArchives__pb2._CHARTFILLSETARCHIVE
_COMMANDAPPLYFILLSETARCHIVE.fields_by_name['rollback_cmd'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDSETSERIESNAMEARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDSETCATEGORYNAMEARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDADDGRIDROWSARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDADDGRIDROWSARCHIVE.fields_by_name['row_id'].message_type = TSPMessages__pb2._UUID
_COMMANDADDGRIDROWSARCHIVE.fields_by_name['row_id_list'].message_type = TSPMessages__pb2._UUID
_COMMANDADDGRIDROWSARCHIVE.fields_by_name['undo_deletion_start_id'].message_type = TSPMessages__pb2._UUID
_COMMANDADDGRIDROWSARCHIVE.fields_by_name['undo_deletion_end_id'].message_type = TSPMessages__pb2._UUID
_COMMANDADDGRIDCOLUMNSARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDADDGRIDCOLUMNSARCHIVE.fields_by_name['column_id'].message_type = TSPMessages__pb2._UUID
_COMMANDADDGRIDCOLUMNSARCHIVE.fields_by_name['column_id_list'].message_type = TSPMessages__pb2._UUID
_COMMANDADDGRIDCOLUMNSARCHIVE.fields_by_name['undo_deletion_start_id'].message_type = TSPMessages__pb2._UUID
_COMMANDADDGRIDCOLUMNSARCHIVE.fields_by_name['undo_deletion_end_id'].message_type = TSPMessages__pb2._UUID
_COMMANDMOVEGRIDROWSARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDMOVEGRIDROWSARCHIVE.fields_by_name['start_row_id'].message_type = TSPMessages__pb2._UUID
_COMMANDMOVEGRIDROWSARCHIVE.fields_by_name['end_row_id'].message_type = TSPMessages__pb2._UUID
_COMMANDMOVEGRIDROWSARCHIVE.fields_by_name['after_row_id'].message_type = TSPMessages__pb2._UUID
_COMMANDMOVEGRIDROWSARCHIVE.fields_by_name['undo_after_row_id'].message_type = TSPMessages__pb2._UUID
_COMMANDMOVEGRIDCOLUMNSARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDMOVEGRIDCOLUMNSARCHIVE.fields_by_name['start_column_id'].message_type = TSPMessages__pb2._UUID
_COMMANDMOVEGRIDCOLUMNSARCHIVE.fields_by_name['end_column_id'].message_type = TSPMessages__pb2._UUID
_COMMANDMOVEGRIDCOLUMNSARCHIVE.fields_by_name['after_column_id'].message_type = TSPMessages__pb2._UUID
_COMMANDMOVEGRIDCOLUMNSARCHIVE.fields_by_name['undo_after_column_id'].message_type = TSPMessages__pb2._UUID
_COMMANDDELETEGRIDROWSARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDDELETEGRIDROWSARCHIVE.fields_by_name['start_row_id'].message_type = TSPMessages__pb2._UUID
_COMMANDDELETEGRIDROWSARCHIVE.fields_by_name['end_row_id'].message_type = TSPMessages__pb2._UUID
_COMMANDDELETEGRIDROWSARCHIVE.fields_by_name['cut_values'].message_type = TSCHArchives__Common__pb2._GRIDROW
_COMMANDDELETEGRIDROWSARCHIVE.fields_by_name['undo_column_insertion_id'].message_type = TSPMessages__pb2._UUID
_COMMANDDELETEGRIDROWSARCHIVE.fields_by_name['undo_row_insertion_id'].message_type = TSPMessages__pb2._UUID
_COMMANDDELETEGRIDROWSARCHIVE.fields_by_name['undo_row_id_list'].message_type = TSPMessages__pb2._UUID
_COMMANDDELETEGRIDROWSARCHIVE.fields_by_name['undo_column_id_list'].message_type = TSPMessages__pb2._UUID
_COMMANDDELETEGRIDCOLUMNSARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDDELETEGRIDCOLUMNSARCHIVE.fields_by_name['start_column_id'].message_type = TSPMessages__pb2._UUID
_COMMANDDELETEGRIDCOLUMNSARCHIVE.fields_by_name['end_column_id'].message_type = TSPMessages__pb2._UUID
_COMMANDDELETEGRIDCOLUMNSARCHIVE.fields_by_name['cut_values'].message_type = TSCHArchives__Common__pb2._GRIDROW
_COMMANDDELETEGRIDCOLUMNSARCHIVE.fields_by_name['undo_column_insertion_id'].message_type = TSPMessages__pb2._UUID
_COMMANDDELETEGRIDCOLUMNSARCHIVE.fields_by_name['undo_row_insertion_id'].message_type = TSPMessages__pb2._UUID
_COMMANDDELETEGRIDCOLUMNSARCHIVE.fields_by_name['undo_column_id_list'].message_type = TSPMessages__pb2._UUID
_COMMANDDELETEGRIDCOLUMNSARCHIVE.fields_by_name['undo_row_id_list'].message_type = TSPMessages__pb2._UUID
_COMMANDSETGRIDVALUEARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDSETGRIDDIRECTIONARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDSETSERIESTYPEARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDSETSCATTERFORMATARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDSETMULTIDATASETINDEXARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDSETLEGENDFRAMEARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDSETLEGENDFRAMEARCHIVE.fields_by_name['old_legend_frame'].message_type = TSCHArchives__Common__pb2._RECTARCHIVE
_COMMANDSETLEGENDFRAMEARCHIVE.fields_by_name['new_legend_frame'].message_type = TSCHArchives__Common__pb2._RECTARCHIVE
_COMMANDSETPIEWEDGEEXPLOSION.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDSETPIEWEDGEEXPLOSION.fields_by_name['rollback_cmd'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCHARTAPPLYTHEME.fields_by_name['super'].message_type = TSSArchives__pb2._APPLYTHEMECHILDCOMMANDARCHIVE
_COMMANDCHARTAPPLYTHEME.fields_by_name['info'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCHARTAPPLYTHEME.fields_by_name['swap_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCHARTAPPLYTHEME.fields_by_name['preset'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCHARTAPPLYPRESET.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDCHARTAPPLYPRESET.fields_by_name['behavior'].enum_type = _APPLYPRESETBEHAVIOR
_COMMANDCHARTAPPLYPRESET.fields_by_name['preset'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCHARTAPPLYPRESET.fields_by_name['old_preset'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCHARTAPPLYPRESET.fields_by_name['swap_tuples'].message_type = _STYLESWAPUNDOTUPLEARCHIVE
_COMMANDCHARTAPPLYPRESET.fields_by_name['inverse_swap_tuples'].message_type = _STYLESWAPUNDOTUPLEARCHIVE
_COMMANDCHARTAPPLYPRESET.fields_by_name['rollback_preset'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCHARTAPPLYPRESET.fields_by_name['rollback_swap_tuples'].message_type = _STYLESWAPUNDOTUPLEARCHIVE
_COMMANDCLEANUPGEOMETRYARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDCLEANUPGEOMETRYARCHIVE.fields_by_name['info_geometry_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCLEANUPGEOMETRYARCHIVE.fields_by_name['anchor_attachment_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDCLEANUPGEOMETRYARCHIVE.fields_by_name['original_legend_rect'].message_type = TSCHArchives__Common__pb2._RECTARCHIVE
_CHARTCOMMANDARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_CHARTCOMMANDARCHIVE.fields_by_name['chart_info'].message_type = TSPMessages__pb2._REFERENCE
_CHARTCOMMANDARCHIVE.fields_by_name['chart_info_id_path'].message_type = TSPMessages__pb2._UUIDPATH
_COMMANDREPLACEGRIDVALUESARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDREPLACEGRIDVALUESARCHIVE.fields_by_name['old_data_rows'].message_type = TSCHArchives__Common__pb2._GRIDROW
_COMMANDREPLACEGRIDVALUESARCHIVE.fields_by_name['new_data_rows'].message_type = TSCHArchives__Common__pb2._GRIDROW
_COMMANDREPLACEGRIDVALUESARCHIVE.fields_by_name['update_row_uuids'].message_type = TSPMessages__pb2._UUID
_COMMANDREPLACEGRIDVALUESARCHIVE.fields_by_name['update_column_uuids'].message_type = TSPMessages__pb2._UUID
_COMMANDREPLACEGRIDVALUESARCHIVE.fields_by_name['add_row_uuids'].message_type = TSPMessages__pb2._UUID
_COMMANDREPLACEGRIDVALUESARCHIVE.fields_by_name['add_column_uuids'].message_type = TSPMessages__pb2._UUID
_COMMANDREPLACEGRIDVALUESARCHIVE.fields_by_name['delete_row_uuids'].message_type = TSPMessages__pb2._UUID
_COMMANDREPLACEGRIDVALUESARCHIVE.fields_by_name['delete_column_uuids'].message_type = TSPMessages__pb2._UUID
_COMMANDREPLACETHEMEPRESETARCHIVE_STYLEANDIDENTIFIERPAIR.fields_by_name['style'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREPLACETHEMEPRESETARCHIVE_STYLEANDIDENTIFIERPAIR.containing_type = _COMMANDREPLACETHEMEPRESETARCHIVE
_COMMANDREPLACETHEMEPRESETARCHIVE.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDREPLACETHEMEPRESETARCHIVE.fields_by_name['theme'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREPLACETHEMEPRESETARCHIVE.fields_by_name['old_preset'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREPLACETHEMEPRESETARCHIVE.fields_by_name['new_preset'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREPLACETHEMEPRESETARCHIVE.fields_by_name['identifiers'].message_type = _COMMANDREPLACETHEMEPRESETARCHIVE_STYLEANDIDENTIFIERPAIR
_COMMANDINVALIDATEWPCACHES.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDREPLACECUSTOMFORMATARCHIVE_FORMATOBJECTMUTATION.fields_by_name['style_owner_type'].enum_type = _STYLEOWNERTYPE
_COMMANDREPLACECUSTOMFORMATARCHIVE_FORMATOBJECTMUTATION.fields_by_name['format_object'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_COMMANDREPLACECUSTOMFORMATARCHIVE_FORMATOBJECTMUTATION.containing_type = _COMMANDREPLACECUSTOMFORMATARCHIVE
_COMMANDREPLACECUSTOMFORMATARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDREPLACECUSTOMFORMATARCHIVE.fields_by_name['rollback_cmd'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREPLACECUSTOMFORMATARCHIVE.fields_by_name['old_format_object'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_COMMANDREPLACECUSTOMFORMATARCHIVE.fields_by_name['new_format_object'].message_type = TSKArchives__pb2._FORMATSTRUCTARCHIVE
_COMMANDREPLACECUSTOMFORMATARCHIVE.fields_by_name['forward_mutations'].message_type = _COMMANDREPLACECUSTOMFORMATARCHIVE_FORMATOBJECTMUTATION
_COMMANDREPLACECUSTOMFORMATARCHIVE.fields_by_name['reverse_mutations'].message_type = _COMMANDREPLACECUSTOMFORMATARCHIVE_FORMATOBJECTMUTATION
_COMMANDADDREFERENCELINEARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDADDREFERENCELINEARCHIVE.fields_by_name['axis_id'].message_type = TSCHArchives__pb2._CHARTAXISIDARCHIVE
_COMMANDADDREFERENCELINEARCHIVE.fields_by_name['uuid'].message_type = TSPMessages__pb2._UUID
_COMMANDADDREFERENCELINEARCHIVE.fields_by_name['non_style'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDADDREFERENCELINEARCHIVE.fields_by_name['style'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDADDREFERENCELINEARCHIVE.fields_by_name['paragraph_styles'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDADDREFERENCELINEARCHIVE.fields_by_name['rollback_commands'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDDELETEREFERENCELINEARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDDELETEREFERENCELINEARCHIVE.fields_by_name['axis_id'].message_type = TSCHArchives__pb2._CHARTAXISIDARCHIVE
_COMMANDDELETEREFERENCELINEARCHIVE.fields_by_name['uuid'].message_type = TSPMessages__pb2._UUID
_COMMANDDELETEREFERENCELINEARCHIVE.fields_by_name['non_style'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDDELETEREFERENCELINEARCHIVE.fields_by_name['style'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDDELETEREFERENCELINEARCHIVE.fields_by_name['paragraph_styles'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDDELETEREFERENCELINEARCHIVE.fields_by_name['style_swap_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDPASTESTYLEARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDPASTESTYLEARCHIVE.fields_by_name['style_swap_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDPASTESTYLEARCHIVE.fields_by_name['inverse_chart_style_state'].message_type = TSCHArchives__pb2._PROPERTYVALUESTORAGECONTAINERARCHIVE
_COMMANDPASTESTYLEARCHIVE.fields_by_name['chart_style_state'].message_type = TSCHArchives__pb2._PROPERTYVALUESTORAGECONTAINERARCHIVE
_COMMANDPASTESTYLEARCHIVE.fields_by_name['shape_style'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDPASTESTYLEARCHIVE.fields_by_name['subselection'].message_type = TSCHArchives__pb2._CHARTSELECTIONPATHARCHIVE
_COMMANDREPLACEIMAGEDATAARCHIVE.fields_by_name['super'].message_type = _CHARTCOMMANDARCHIVE
_COMMANDREPLACEIMAGEDATAARCHIVE.fields_by_name['style_swap_command'].message_type = TSPMessages__pb2._REFERENCE
_COMMANDREPLACEIMAGEDATAARCHIVE.fields_by_name['inverse_chart_style_state'].message_type = TSCHArchives__pb2._PROPERTYVALUESTORAGECONTAINERARCHIVE
_COMMANDREPLACEIMAGEDATAARCHIVE.fields_by_name['chart_style_state'].message_type = TSCHArchives__pb2._PROPERTYVALUESTORAGECONTAINERARCHIVE
_COMMANDINDUCEDREPLACECHARTGRID.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_COMMANDINDUCED3DCHARTGEOMETRY.fields_by_name['super'].message_type = TSKArchives__pb2._COMMANDARCHIVE
_CHARTTEXTSELECTIONTRANSFORMERARCHIVE.fields_by_name['selection'].message_type = TSPMessages__pb2._REFERENCE
_CHARTDRAWABLESELECTIONTRANSFORMERARCHIVE.fields_by_name['super'].message_type = TSDCommandArchives__pb2._DRAWABLESELECTIONTRANSFORMERARCHIVE
_CHARTSUBSELECTIONTRANSFORMERHELPERARCHIVE.fields_by_name['selection'].message_type = TSPMessages__pb2._REFERENCE
_CHARTREFLINESUBSELECTIONTRANSFORMERHELPERARCHIVE.fields_by_name['super'].message_type = _CHARTSUBSELECTIONTRANSFORMERHELPERARCHIVE
_CHARTREFLINESUBSELECTIONTRANSFORMERHELPERARCHIVE.fields_by_name['selected_reference_line_uuids'].message_type = TSPMessages__pb2._UUID
_CHARTSUBSELECTIONIDENTITYTRANSFORMERHELPERARCHIVE.fields_by_name['super'].message_type = _CHARTSUBSELECTIONTRANSFORMERHELPERARCHIVE
_CHARTSUBSELECTIONTRANSFORMERARCHIVE.fields_by_name['selection'].message_type = TSPMessages__pb2._REFERENCE
_CHARTSUBSELECTIONTRANSFORMERARCHIVE.fields_by_name['helper'].message_type = TSPMessages__pb2._REFERENCE
_CDESELECTIONTRANSFORMERARCHIVE.fields_by_name['cde_selection'].message_type = TSPMessages__pb2._REFERENCE
DESCRIPTOR.message_types_by_name['StyleOwnerPath'] = _STYLEOWNERPATH
DESCRIPTOR.message_types_by_name['CommandSetChartTypeArchive'] = _COMMANDSETCHARTTYPEARCHIVE
DESCRIPTOR.message_types_by_name['StyleSwapUndoTupleArchive'] = _STYLESWAPUNDOTUPLEARCHIVE
DESCRIPTOR.message_types_by_name['StyleSwapUndoTuplesArchive'] = _STYLESWAPUNDOTUPLESARCHIVE
DESCRIPTOR.message_types_by_name['CommandStyleSwapArchive'] = _COMMANDSTYLESWAPARCHIVE
DESCRIPTOR.message_types_by_name['CommandMutatePropertiesArchive'] = _COMMANDMUTATEPROPERTIESARCHIVE
DESCRIPTOR.message_types_by_name['CommandScaleAllTextArchive'] = _COMMANDSCALEALLTEXTARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetFontFamilyArchive'] = _COMMANDSETFONTFAMILYARCHIVE
DESCRIPTOR.message_types_by_name['CommandApplyFillSetArchive'] = _COMMANDAPPLYFILLSETARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetSeriesNameArchive'] = _COMMANDSETSERIESNAMEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetCategoryNameArchive'] = _COMMANDSETCATEGORYNAMEARCHIVE
DESCRIPTOR.message_types_by_name['CommandAddGridRowsArchive'] = _COMMANDADDGRIDROWSARCHIVE
DESCRIPTOR.message_types_by_name['CommandAddGridColumnsArchive'] = _COMMANDADDGRIDCOLUMNSARCHIVE
DESCRIPTOR.message_types_by_name['CommandMoveGridRowsArchive'] = _COMMANDMOVEGRIDROWSARCHIVE
DESCRIPTOR.message_types_by_name['CommandMoveGridColumnsArchive'] = _COMMANDMOVEGRIDCOLUMNSARCHIVE
DESCRIPTOR.message_types_by_name['CommandDeleteGridRowsArchive'] = _COMMANDDELETEGRIDROWSARCHIVE
DESCRIPTOR.message_types_by_name['CommandDeleteGridColumnsArchive'] = _COMMANDDELETEGRIDCOLUMNSARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetGridValueArchive'] = _COMMANDSETGRIDVALUEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetGridDirectionArchive'] = _COMMANDSETGRIDDIRECTIONARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetSeriesTypeArchive'] = _COMMANDSETSERIESTYPEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetScatterFormatArchive'] = _COMMANDSETSCATTERFORMATARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetMultiDataSetIndexArchive'] = _COMMANDSETMULTIDATASETINDEXARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetLegendFrameArchive'] = _COMMANDSETLEGENDFRAMEARCHIVE
DESCRIPTOR.message_types_by_name['CommandSetPieWedgeExplosion'] = _COMMANDSETPIEWEDGEEXPLOSION
DESCRIPTOR.message_types_by_name['CommandChartApplyTheme'] = _COMMANDCHARTAPPLYTHEME
DESCRIPTOR.message_types_by_name['CommandChartApplyPreset'] = _COMMANDCHARTAPPLYPRESET
DESCRIPTOR.message_types_by_name['CommandCleanupGeometryArchive'] = _COMMANDCLEANUPGEOMETRYARCHIVE
DESCRIPTOR.message_types_by_name['ChartCommandArchive'] = _CHARTCOMMANDARCHIVE
DESCRIPTOR.message_types_by_name['CommandReplaceGridValuesArchive'] = _COMMANDREPLACEGRIDVALUESARCHIVE
DESCRIPTOR.message_types_by_name['CommandReplaceThemePresetArchive'] = _COMMANDREPLACETHEMEPRESETARCHIVE
DESCRIPTOR.message_types_by_name['CommandInvalidateWPCaches'] = _COMMANDINVALIDATEWPCACHES
DESCRIPTOR.message_types_by_name['CommandReplaceCustomFormatArchive'] = _COMMANDREPLACECUSTOMFORMATARCHIVE
DESCRIPTOR.message_types_by_name['CommandAddReferenceLineArchive'] = _COMMANDADDREFERENCELINEARCHIVE
DESCRIPTOR.message_types_by_name['CommandDeleteReferenceLineArchive'] = _COMMANDDELETEREFERENCELINEARCHIVE
DESCRIPTOR.message_types_by_name['CommandPasteStyleArchive'] = _COMMANDPASTESTYLEARCHIVE
DESCRIPTOR.message_types_by_name['CommandReplaceImageDataArchive'] = _COMMANDREPLACEIMAGEDATAARCHIVE
DESCRIPTOR.message_types_by_name['CommandInducedReplaceChartGrid'] = _COMMANDINDUCEDREPLACECHARTGRID
DESCRIPTOR.message_types_by_name['CommandInduced3DChartGeometry'] = _COMMANDINDUCED3DCHARTGEOMETRY
DESCRIPTOR.message_types_by_name['ChartTextSelectionTransformerArchive'] = _CHARTTEXTSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['ChartDrawableSelectionTransformerArchive'] = _CHARTDRAWABLESELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['ChartSubselectionTransformerHelperArchive'] = _CHARTSUBSELECTIONTRANSFORMERHELPERARCHIVE
DESCRIPTOR.message_types_by_name['ChartRefLineSubselectionTransformerHelperArchive'] = _CHARTREFLINESUBSELECTIONTRANSFORMERHELPERARCHIVE
DESCRIPTOR.message_types_by_name['ChartSubselectionIdentityTransformerHelperArchive'] = _CHARTSUBSELECTIONIDENTITYTRANSFORMERHELPERARCHIVE
DESCRIPTOR.message_types_by_name['ChartSubselectionTransformerArchive'] = _CHARTSUBSELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.message_types_by_name['CDESelectionTransformerArchive'] = _CDESELECTIONTRANSFORMERARCHIVE
DESCRIPTOR.enum_types_by_name['StyleOwnerType'] = _STYLEOWNERTYPE
DESCRIPTOR.enum_types_by_name['StyleSwapType'] = _STYLESWAPTYPE
DESCRIPTOR.enum_types_by_name['ApplyPresetBehavior'] = _APPLYPRESETBEHAVIOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StyleOwnerPath = _reflection.GeneratedProtocolMessageType('StyleOwnerPath', (_message.Message,), dict(
  DESCRIPTOR = _STYLEOWNERPATH,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.StyleOwnerPath)
  ))
_sym_db.RegisterMessage(StyleOwnerPath)

CommandSetChartTypeArchive = _reflection.GeneratedProtocolMessageType('CommandSetChartTypeArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETCHARTTYPEARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandSetChartTypeArchive)
  ))
_sym_db.RegisterMessage(CommandSetChartTypeArchive)

StyleSwapUndoTupleArchive = _reflection.GeneratedProtocolMessageType('StyleSwapUndoTupleArchive', (_message.Message,), dict(
  DESCRIPTOR = _STYLESWAPUNDOTUPLEARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.StyleSwapUndoTupleArchive)
  ))
_sym_db.RegisterMessage(StyleSwapUndoTupleArchive)

StyleSwapUndoTuplesArchive = _reflection.GeneratedProtocolMessageType('StyleSwapUndoTuplesArchive', (_message.Message,), dict(
  DESCRIPTOR = _STYLESWAPUNDOTUPLESARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.StyleSwapUndoTuplesArchive)
  ))
_sym_db.RegisterMessage(StyleSwapUndoTuplesArchive)

CommandStyleSwapArchive = _reflection.GeneratedProtocolMessageType('CommandStyleSwapArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSTYLESWAPARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandStyleSwapArchive)
  ))
_sym_db.RegisterMessage(CommandStyleSwapArchive)

CommandMutatePropertiesArchive = _reflection.GeneratedProtocolMessageType('CommandMutatePropertiesArchive', (_message.Message,), dict(

  GenericPropertyDeltaMap = _reflection.GeneratedProtocolMessageType('GenericPropertyDeltaMap', (_message.Message,), dict(

    GenericMapUnion = _reflection.GeneratedProtocolMessageType('GenericMapUnion', (_message.Message,), dict(
      DESCRIPTOR = _COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP_GENERICMAPUNION,
      __module__ = 'TSCHCommandArchives_pb2'
      # @@protoc_insertion_point(class_scope:TSCH.CommandMutatePropertiesArchive.GenericPropertyDeltaMap.GenericMapUnion)
      ))
    ,
    DESCRIPTOR = _COMMANDMUTATEPROPERTIESARCHIVE_GENERICPROPERTYDELTAMAP,
    __module__ = 'TSCHCommandArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCH.CommandMutatePropertiesArchive.GenericPropertyDeltaMap)
    ))
  ,

  ParagraphStyleDeltaMap = _reflection.GeneratedProtocolMessageType('ParagraphStyleDeltaMap', (_message.Message,), dict(

    ParagraphStylePropertyMapArchive = _reflection.GeneratedProtocolMessageType('ParagraphStylePropertyMapArchive', (_message.Message,), dict(
      DESCRIPTOR = _COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP_PARAGRAPHSTYLEPROPERTYMAPARCHIVE,
      __module__ = 'TSCHCommandArchives_pb2'
      # @@protoc_insertion_point(class_scope:TSCH.CommandMutatePropertiesArchive.ParagraphStyleDeltaMap.ParagraphStylePropertyMapArchive)
      ))
    ,
    DESCRIPTOR = _COMMANDMUTATEPROPERTIESARCHIVE_PARAGRAPHSTYLEDELTAMAP,
    __module__ = 'TSCHCommandArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCH.CommandMutatePropertiesArchive.ParagraphStyleDeltaMap)
    ))
  ,
  DESCRIPTOR = _COMMANDMUTATEPROPERTIESARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandMutatePropertiesArchive)
  ))
_sym_db.RegisterMessage(CommandMutatePropertiesArchive)
_sym_db.RegisterMessage(CommandMutatePropertiesArchive.GenericPropertyDeltaMap)
_sym_db.RegisterMessage(CommandMutatePropertiesArchive.GenericPropertyDeltaMap.GenericMapUnion)
_sym_db.RegisterMessage(CommandMutatePropertiesArchive.ParagraphStyleDeltaMap)
_sym_db.RegisterMessage(CommandMutatePropertiesArchive.ParagraphStyleDeltaMap.ParagraphStylePropertyMapArchive)

CommandScaleAllTextArchive = _reflection.GeneratedProtocolMessageType('CommandScaleAllTextArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSCALEALLTEXTARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandScaleAllTextArchive)
  ))
_sym_db.RegisterMessage(CommandScaleAllTextArchive)

CommandSetFontFamilyArchive = _reflection.GeneratedProtocolMessageType('CommandSetFontFamilyArchive', (_message.Message,), dict(

  StyleSemanticTag = _reflection.GeneratedProtocolMessageType('StyleSemanticTag', (_message.Message,), dict(
    DESCRIPTOR = _COMMANDSETFONTFAMILYARCHIVE_STYLESEMANTICTAG,
    __module__ = 'TSCHCommandArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCH.CommandSetFontFamilyArchive.StyleSemanticTag)
    ))
  ,

  SemanticParagraphStyleMutationMap = _reflection.GeneratedProtocolMessageType('SemanticParagraphStyleMutationMap', (_message.Message,), dict(

    ParagraphStylePropertyMapArchive = _reflection.GeneratedProtocolMessageType('ParagraphStylePropertyMapArchive', (_message.Message,), dict(
      DESCRIPTOR = _COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP_PARAGRAPHSTYLEPROPERTYMAPARCHIVE,
      __module__ = 'TSCHCommandArchives_pb2'
      # @@protoc_insertion_point(class_scope:TSCH.CommandSetFontFamilyArchive.SemanticParagraphStyleMutationMap.ParagraphStylePropertyMapArchive)
      ))
    ,
    DESCRIPTOR = _COMMANDSETFONTFAMILYARCHIVE_SEMANTICPARAGRAPHSTYLEMUTATIONMAP,
    __module__ = 'TSCHCommandArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCH.CommandSetFontFamilyArchive.SemanticParagraphStyleMutationMap)
    ))
  ,
  DESCRIPTOR = _COMMANDSETFONTFAMILYARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandSetFontFamilyArchive)
  ))
_sym_db.RegisterMessage(CommandSetFontFamilyArchive)
_sym_db.RegisterMessage(CommandSetFontFamilyArchive.StyleSemanticTag)
_sym_db.RegisterMessage(CommandSetFontFamilyArchive.SemanticParagraphStyleMutationMap)
_sym_db.RegisterMessage(CommandSetFontFamilyArchive.SemanticParagraphStyleMutationMap.ParagraphStylePropertyMapArchive)

CommandApplyFillSetArchive = _reflection.GeneratedProtocolMessageType('CommandApplyFillSetArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDAPPLYFILLSETARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandApplyFillSetArchive)
  ))
_sym_db.RegisterMessage(CommandApplyFillSetArchive)

CommandSetSeriesNameArchive = _reflection.GeneratedProtocolMessageType('CommandSetSeriesNameArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETSERIESNAMEARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandSetSeriesNameArchive)
  ))
_sym_db.RegisterMessage(CommandSetSeriesNameArchive)

CommandSetCategoryNameArchive = _reflection.GeneratedProtocolMessageType('CommandSetCategoryNameArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETCATEGORYNAMEARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandSetCategoryNameArchive)
  ))
_sym_db.RegisterMessage(CommandSetCategoryNameArchive)

CommandAddGridRowsArchive = _reflection.GeneratedProtocolMessageType('CommandAddGridRowsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDADDGRIDROWSARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandAddGridRowsArchive)
  ))
_sym_db.RegisterMessage(CommandAddGridRowsArchive)

CommandAddGridColumnsArchive = _reflection.GeneratedProtocolMessageType('CommandAddGridColumnsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDADDGRIDCOLUMNSARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandAddGridColumnsArchive)
  ))
_sym_db.RegisterMessage(CommandAddGridColumnsArchive)

CommandMoveGridRowsArchive = _reflection.GeneratedProtocolMessageType('CommandMoveGridRowsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDMOVEGRIDROWSARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandMoveGridRowsArchive)
  ))
_sym_db.RegisterMessage(CommandMoveGridRowsArchive)

CommandMoveGridColumnsArchive = _reflection.GeneratedProtocolMessageType('CommandMoveGridColumnsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDMOVEGRIDCOLUMNSARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandMoveGridColumnsArchive)
  ))
_sym_db.RegisterMessage(CommandMoveGridColumnsArchive)

CommandDeleteGridRowsArchive = _reflection.GeneratedProtocolMessageType('CommandDeleteGridRowsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDDELETEGRIDROWSARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandDeleteGridRowsArchive)
  ))
_sym_db.RegisterMessage(CommandDeleteGridRowsArchive)

CommandDeleteGridColumnsArchive = _reflection.GeneratedProtocolMessageType('CommandDeleteGridColumnsArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDDELETEGRIDCOLUMNSARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandDeleteGridColumnsArchive)
  ))
_sym_db.RegisterMessage(CommandDeleteGridColumnsArchive)

CommandSetGridValueArchive = _reflection.GeneratedProtocolMessageType('CommandSetGridValueArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETGRIDVALUEARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandSetGridValueArchive)
  ))
_sym_db.RegisterMessage(CommandSetGridValueArchive)

CommandSetGridDirectionArchive = _reflection.GeneratedProtocolMessageType('CommandSetGridDirectionArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETGRIDDIRECTIONARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandSetGridDirectionArchive)
  ))
_sym_db.RegisterMessage(CommandSetGridDirectionArchive)

CommandSetSeriesTypeArchive = _reflection.GeneratedProtocolMessageType('CommandSetSeriesTypeArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETSERIESTYPEARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandSetSeriesTypeArchive)
  ))
_sym_db.RegisterMessage(CommandSetSeriesTypeArchive)

CommandSetScatterFormatArchive = _reflection.GeneratedProtocolMessageType('CommandSetScatterFormatArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETSCATTERFORMATARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandSetScatterFormatArchive)
  ))
_sym_db.RegisterMessage(CommandSetScatterFormatArchive)

CommandSetMultiDataSetIndexArchive = _reflection.GeneratedProtocolMessageType('CommandSetMultiDataSetIndexArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETMULTIDATASETINDEXARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandSetMultiDataSetIndexArchive)
  ))
_sym_db.RegisterMessage(CommandSetMultiDataSetIndexArchive)

CommandSetLegendFrameArchive = _reflection.GeneratedProtocolMessageType('CommandSetLegendFrameArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETLEGENDFRAMEARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandSetLegendFrameArchive)
  ))
_sym_db.RegisterMessage(CommandSetLegendFrameArchive)

CommandSetPieWedgeExplosion = _reflection.GeneratedProtocolMessageType('CommandSetPieWedgeExplosion', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDSETPIEWEDGEEXPLOSION,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandSetPieWedgeExplosion)
  ))
_sym_db.RegisterMessage(CommandSetPieWedgeExplosion)

CommandChartApplyTheme = _reflection.GeneratedProtocolMessageType('CommandChartApplyTheme', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDCHARTAPPLYTHEME,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandChartApplyTheme)
  ))
_sym_db.RegisterMessage(CommandChartApplyTheme)

CommandChartApplyPreset = _reflection.GeneratedProtocolMessageType('CommandChartApplyPreset', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDCHARTAPPLYPRESET,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandChartApplyPreset)
  ))
_sym_db.RegisterMessage(CommandChartApplyPreset)

CommandCleanupGeometryArchive = _reflection.GeneratedProtocolMessageType('CommandCleanupGeometryArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDCLEANUPGEOMETRYARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandCleanupGeometryArchive)
  ))
_sym_db.RegisterMessage(CommandCleanupGeometryArchive)

ChartCommandArchive = _reflection.GeneratedProtocolMessageType('ChartCommandArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTCOMMANDARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartCommandArchive)
  ))
_sym_db.RegisterMessage(ChartCommandArchive)

CommandReplaceGridValuesArchive = _reflection.GeneratedProtocolMessageType('CommandReplaceGridValuesArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREPLACEGRIDVALUESARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandReplaceGridValuesArchive)
  ))
_sym_db.RegisterMessage(CommandReplaceGridValuesArchive)

CommandReplaceThemePresetArchive = _reflection.GeneratedProtocolMessageType('CommandReplaceThemePresetArchive', (_message.Message,), dict(

  StyleAndIdentifierPair = _reflection.GeneratedProtocolMessageType('StyleAndIdentifierPair', (_message.Message,), dict(
    DESCRIPTOR = _COMMANDREPLACETHEMEPRESETARCHIVE_STYLEANDIDENTIFIERPAIR,
    __module__ = 'TSCHCommandArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCH.CommandReplaceThemePresetArchive.StyleAndIdentifierPair)
    ))
  ,
  DESCRIPTOR = _COMMANDREPLACETHEMEPRESETARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandReplaceThemePresetArchive)
  ))
_sym_db.RegisterMessage(CommandReplaceThemePresetArchive)
_sym_db.RegisterMessage(CommandReplaceThemePresetArchive.StyleAndIdentifierPair)

CommandInvalidateWPCaches = _reflection.GeneratedProtocolMessageType('CommandInvalidateWPCaches', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDINVALIDATEWPCACHES,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandInvalidateWPCaches)
  ))
_sym_db.RegisterMessage(CommandInvalidateWPCaches)

CommandReplaceCustomFormatArchive = _reflection.GeneratedProtocolMessageType('CommandReplaceCustomFormatArchive', (_message.Message,), dict(

  FormatObjectMutation = _reflection.GeneratedProtocolMessageType('FormatObjectMutation', (_message.Message,), dict(
    DESCRIPTOR = _COMMANDREPLACECUSTOMFORMATARCHIVE_FORMATOBJECTMUTATION,
    __module__ = 'TSCHCommandArchives_pb2'
    # @@protoc_insertion_point(class_scope:TSCH.CommandReplaceCustomFormatArchive.FormatObjectMutation)
    ))
  ,
  DESCRIPTOR = _COMMANDREPLACECUSTOMFORMATARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandReplaceCustomFormatArchive)
  ))
_sym_db.RegisterMessage(CommandReplaceCustomFormatArchive)
_sym_db.RegisterMessage(CommandReplaceCustomFormatArchive.FormatObjectMutation)

CommandAddReferenceLineArchive = _reflection.GeneratedProtocolMessageType('CommandAddReferenceLineArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDADDREFERENCELINEARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandAddReferenceLineArchive)
  ))
_sym_db.RegisterMessage(CommandAddReferenceLineArchive)

CommandDeleteReferenceLineArchive = _reflection.GeneratedProtocolMessageType('CommandDeleteReferenceLineArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDDELETEREFERENCELINEARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandDeleteReferenceLineArchive)
  ))
_sym_db.RegisterMessage(CommandDeleteReferenceLineArchive)

CommandPasteStyleArchive = _reflection.GeneratedProtocolMessageType('CommandPasteStyleArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDPASTESTYLEARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandPasteStyleArchive)
  ))
_sym_db.RegisterMessage(CommandPasteStyleArchive)

CommandReplaceImageDataArchive = _reflection.GeneratedProtocolMessageType('CommandReplaceImageDataArchive', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDREPLACEIMAGEDATAARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandReplaceImageDataArchive)
  ))
_sym_db.RegisterMessage(CommandReplaceImageDataArchive)

CommandInducedReplaceChartGrid = _reflection.GeneratedProtocolMessageType('CommandInducedReplaceChartGrid', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDINDUCEDREPLACECHARTGRID,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandInducedReplaceChartGrid)
  ))
_sym_db.RegisterMessage(CommandInducedReplaceChartGrid)

CommandInduced3DChartGeometry = _reflection.GeneratedProtocolMessageType('CommandInduced3DChartGeometry', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDINDUCED3DCHARTGEOMETRY,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CommandInduced3DChartGeometry)
  ))
_sym_db.RegisterMessage(CommandInduced3DChartGeometry)

ChartTextSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('ChartTextSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTTEXTSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartTextSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(ChartTextSelectionTransformerArchive)

ChartDrawableSelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('ChartDrawableSelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTDRAWABLESELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartDrawableSelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(ChartDrawableSelectionTransformerArchive)

ChartSubselectionTransformerHelperArchive = _reflection.GeneratedProtocolMessageType('ChartSubselectionTransformerHelperArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSUBSELECTIONTRANSFORMERHELPERARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartSubselectionTransformerHelperArchive)
  ))
_sym_db.RegisterMessage(ChartSubselectionTransformerHelperArchive)

ChartRefLineSubselectionTransformerHelperArchive = _reflection.GeneratedProtocolMessageType('ChartRefLineSubselectionTransformerHelperArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTREFLINESUBSELECTIONTRANSFORMERHELPERARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartRefLineSubselectionTransformerHelperArchive)
  ))
_sym_db.RegisterMessage(ChartRefLineSubselectionTransformerHelperArchive)

ChartSubselectionIdentityTransformerHelperArchive = _reflection.GeneratedProtocolMessageType('ChartSubselectionIdentityTransformerHelperArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSUBSELECTIONIDENTITYTRANSFORMERHELPERARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartSubselectionIdentityTransformerHelperArchive)
  ))
_sym_db.RegisterMessage(ChartSubselectionIdentityTransformerHelperArchive)

ChartSubselectionTransformerArchive = _reflection.GeneratedProtocolMessageType('ChartSubselectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _CHARTSUBSELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.ChartSubselectionTransformerArchive)
  ))
_sym_db.RegisterMessage(ChartSubselectionTransformerArchive)

CDESelectionTransformerArchive = _reflection.GeneratedProtocolMessageType('CDESelectionTransformerArchive', (_message.Message,), dict(
  DESCRIPTOR = _CDESELECTIONTRANSFORMERARCHIVE,
  __module__ = 'TSCHCommandArchives_pb2'
  # @@protoc_insertion_point(class_scope:TSCH.CDESelectionTransformerArchive)
  ))
_sym_db.RegisterMessage(CDESelectionTransformerArchive)


# @@protoc_insertion_point(module_scope)
